<?php namespace UpsEuWoocommerce\controllers\admin;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-config-package-dimension.php - The core plugin class.
 * 
 * This is used to config Package Dimension.
 */

include_once(dirname(__FILE__, 3) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_Config_Package_Dimension');

class Ups_Eu_Woo_Config_Package_Dimension
{

    /**
     * Name function: package_dimension
     * Params: empty
     * Return: void
     */
    public function ups_eu_woo_config_package_dimension()
    {
        /* Load all class or models */
        $router_url = new \UpsEuWoocommerce\models\bases\Ups_Eu_Woo_Router_Url();
        $model_config = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Config();
        $model_package = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Package_Default();

        /* Created object */
        $dataObject = new \stdClass();
        /* Init  data */
        $check_save_success = 0;
        $dataObject->validate = [];

        /* submit form */
        if ($router_url->ups_eu_woo_check_method_post() === true) {
            /* get btn controller */
            $btn_controller = "";
            if (!empty($_REQUEST[$router_url->btn_controller])) {
                $btn_controller = trim(sanitize_text_field(strip_tags($_REQUEST[$router_url->btn_controller])));
            }

            /* Get data form post */
            $data_post = $_REQUEST;
            // merge data post to model [PakageDetault]
            $model_package->ups_eu_woo_merge_array($data_post);
            $validate = $model_package->ups_eu_woo_validate();
            /* set validate to form */
            $dataObject->validate = $validate;

            /* add new package */
            if ($btn_controller == 'add-package' && $validate === true) {
                /* save data */
                $model_package->ups_eu_woo_save($data_post);
                $check_save_success = 1;
                if ($model_package->package_id === 1) {
                    if ($model_config->ups_eu_woo_get_by_key($model_config->ups_shipping_check_manage) === true &&
                        intval($model_config->value) === 1
                    ) {
                        call_user_func_array([
                            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Retry_Api(),
                            "ups_eu_woo_transfer_default_package"
                        ], []);
                    }
                }
                /* set blank form view */
                $model_package = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Package_Default();
                /* redirect to DELIVERY RATE page */
                $model_config->ups_eu_woo_set_value_config_by_key(
                    "{$model_config->ACCEPT_PACKAGE_DIMENSION}", 1, $model_config->btn_controller_save
                );
            }

            /* action click button NEXT */
            if ($btn_controller === "{$model_config->btn_controller_next}") {
                $this->ups_eu_woo_action_next();
            } else {
                $model_config->ups_eu_woo_set_value_config_by_key(
                    "{$model_config->ACCEPT_PACKAGE_DIMENSION}", 1, $model_config->btn_controller_save
                );
            }
        }

        /* set fields from model to view */
        $dataObject->model_package = (array) $model_package;
        /* get list all package */
        $dataObject->packages = $model_package->get_list_data_by_condition();
        /* get unit weight list */
        $options = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Options();
        $dataObject->get_unit_weight_list = $options->get_unit_weight_list();
        /* get unit dimension list */
        $options = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Options();
        $dataObject->get_unit_dimension_list = $options->get_unit_dimension_list();
        /* set language */
        $dataObject->lang = \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::ups_eu_woo_get_lang_by_key(
                $model_package->lang_page_package_dimension
        );
        /* status save success */
        $dataObject->check_save_success = $check_save_success;
        /* set number block show */
        $dataObject->number_block_show = $router_url->ups_eu_woo_get_number_block_show(
            $router_url->block_package_dimension, 5
        );
        /* get action form  url */
        $dataObject->action_form = $router_url->url_package_dimension;
        /* get all link form in system */
        $dataObject->links_form = $router_url->ups_eu_woo_get_all_link_form();
        /* get key system  of page currrent */
        $dataObject->ACCEPT_PACKAGE_DIMENSION = "";
        if ($model_config->ups_eu_woo_get_by_key("{$model_config->ACCEPT_PACKAGE_DIMENSION}") === true) {
            $dataObject->ACCEPT_PACKAGE_DIMENSION = $model_config->value;
        }
        $dataObject->page = $router_url->block_package_dimension;

        return $dataObject;
    }

    /**
     * Name function: ups_eu_woo_action_next
     * Params: empty
     * Return: void
     */
    private function ups_eu_woo_action_next()
    {
        $router_url = new \UpsEuWoocommerce\models\bases\Ups_Eu_Woo_Router_Url();
        $model_config = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Config();
        if ($model_config->ups_eu_woo_get_by_key("{$model_config->ACCEPT_PACKAGE_DIMENSION}") === true &&
            intval($model_config->value) === 2) {
            $router_url->ups_eu_woo_redirect($router_url->url_package_dimension);
        }
        $model_config->ups_eu_woo_set_value_config_by_key(
            "{$model_config->ACCEPT_DELIVERY_RATES}", 2, $model_config->btn_controller_next
        );
        $router_url->ups_eu_woo_redirect($router_url->url_delivery_rate);
    }
}
