<?php namespace UpsEuWoocommerce\libsystems\ajax_json;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-ajax-json-shipcreate.php - The core plugin class.
 * 
 * This is used to define some methods to handle the Create Shipment.
 */

include_once(dirname(__FILE__, 3) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_ShipCreate_Ajax_Json');

class Ups_Eu_Woo_ShipCreate_Ajax_Json extends Ups_Eu_Woo_ShipBase_Ajax_Json
{
    /*
     * Name function: __construct
     * Params:
     *  @domain: type string
     * Return: type void
     * * */

    public function __construct()
    {
        /* call parent construct */
        parent::__construct();
    }

    public function ups_eu_woo_config_create_single_shipment()
    {
        if ($_SERVER['REQUEST_METHOD'] != 'POST') {
            http_response_code(403);
        } else {
            $data_post = $_REQUEST;
            $jsonObject = new \stdClass();
            $router_url = new \UpsEuWoocommerce\models\bases\Ups_Eu_Woo_Router_Url();
            $UpsEuWoocommerceSmarty = new \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Smarty();

            //load neccessary model
            $model_service = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Services();
            $model_accessorial = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Accessorial();
            $model_package = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Package_Default();
            $model_option = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Options();
            $model_config = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Config();

            $smarty = $UpsEuWoocommerceSmarty->ups_eu_woo_get_smarty();
            $dataObject = new \stdClass();
            $dataObject->lang = \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::ups_eu_woo_get_lang_by_key(
                    $UpsEuWoocommerceSmarty->lang_page_open_orders
            );
            $dataObject->router_url = $router_url;
            $dataObject->list_account = $this->ups_eu_woo_get_list_account();
            $dataObject->list_package = $model_package->ups_eu_woo_get_all();

            //get all shipping service
            $model_config->ups_eu_woo_get_by_key("COUNTRY_CODE");
            $country_code = $model_config->value;
            $services_to_ap = $model_service->get_list_data_by_condition([
                'service_type = "AP"',
                'country_code = "' . $country_code . '"'
            ]);
            $services_to_add = $model_service->get_list_data_by_condition([
                'service_type = "ADD"',
                'country_code = "' . $country_code . '"'
            ]);
            $dataObject->services_to_ap = [];
            if (!empty($services_to_ap)) {
                $dataObject->services_to_ap = $services_to_ap;
            }
            $dataObject->services_to_add = [];
            if (!empty($services_to_add)) {
                $dataObject->services_to_add = $services_to_add;
            }

            //get all accessorial
            $accessorial = $model_accessorial->ups_eu_woo_get_all();
            $accessorial_translate = \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::ups_eu_woo_get_lang_by_key(
                    $UpsEuWoocommerceSmarty->lang_common
            );
            if (!empty($accessorial)) {
                foreach ($accessorial as $key => $item) {
                    $accessorial[$key]->accessorial_name = $accessorial_translate[$item->accessorial_key];
                }
            }
            $dataObject->list_accessorials = $accessorial;

            //get list country and state
            $country = new \WC_Countries();
            $dataObject->list_country = $country->get_countries();
            $state_data = $country->load_country_states();
            $dataObject->list_state = $country->states;

            $order_id = $data_post['list_id_orders'];
            $list_order = $this->ups_eu_woo_get_order_detail($order_id);
            if (is_numeric($order_id)) {
                $order_detail = $list_order[$order_id];
            } else {
                $order_detail = $list_order;
            }

            $smarty->assign($UpsEuWoocommerceSmarty->dataObject, $dataObject);
            $jsonObject->html = $smarty->fetch("admin/merchant_cf/orders/popups/content_single_shipment.tpl");
            $jsonObject->code = "200";
            $jsonObject->list_account = $dataObject->list_account;
            $jsonObject->order_detail = $order_detail;
            $jsonObject->address_text = $smarty->fetch("admin/merchant_cf/orders/component/info_shipto.tpl");
            return $jsonObject;
        }
    }

    public function ups_eu_woo_config_create_shipment()
    {
        $model_order = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Orders();
        $check = true;
        $message = "";
        $result_data = array();

        if ($_SERVER['REQUEST_METHOD'] != 'POST') {
            http_response_code(403);
        } else {
            $data_post = $_REQUEST;
            $package = $data_post[$model_order->package];
            $check_edit = $data_post[$model_order->edit_shipment];
            $ship_to = $data_post[$model_order->ship_to];
            $shipping_type = $data_post[$model_order->shipping_type];
            $validate_package = $this->ups_eu_woo_validate_package($package);
            $validate_edit = $this->ups_eu_woo_validate_edit_shipment($check_edit, $ship_to, $shipping_type);
            $error_message = $validate_edit[1];

            if ($validate_package[0] && $validate_edit[0]) {
                $create_result = $this->ups_eu_woo_exec_create_shipment($data_post);
                $check = $create_result[0];
                $message = $create_result[1];
            } else {
                $check = false;
                if ($validate_edit[0]) {
                    $message = $this->package_error;
                    $result_data = $validate_package[1];
                } elseif ($validate_package[0]) {
                    $message = implode($model_order->html_br, $this->ups_eu_woo_add_array($error_message));
                    $result_data = $validate_edit[2];
                } else {
                    $error_message[] = $this->package_error;
                    $message = implode($model_order->html_br, $this->ups_eu_woo_add_array($error_message));
                    $result_data = array($validate_edit[2], $validate_package[1]);
                }
            }

            $dataObject = new \stdClass();
            $dataObject->code = "200";
            $dataObject->check = $check;
            $dataObject->message = $message;
            $dataObject->result = $result_data;
            $dataObject->validate = [$validate_edit[0], $validate_package[0]];
            return $dataObject;
        }
    }

}
