<?php namespace UpsEuWoocommerce\libsystems\api_ups;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-call-api-ups-eshopper.php - The core plugin class.
 * 
 * This is used to define some methods to get information from Ups API for e-shopper.
 */

include_once(dirname(__FILE__, 3) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_EShopper_Api_Ups');

class Ups_Eu_Woo_EShopper_Api_Ups extends Ups_Eu_Woo_Global_Api_Ups implements Ups_Eu_Woo_Interfaces_Api_Ups
{

    public function __construct()
    {
        parent::__construct();
    }

    public function ups_eu_woo_search_locator($data_array = [])
    {
        $object_call = new \stdClass();
        $object_call->check_api_all = false;
        call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(),
            "ups_eu_woo_input_params_ajax"
            ], [
            &$object_call
            ]
        );
        /* ---call lactor---- */
        $object_call->info_locator = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(),
            "ups_eu_woo_process_data_locator"
            ], [
            $this->ups_eu_woo_call_locator($object_call, true), &$object_call, true
            ]
        );
        $object_call->html = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), "ups_eu_woo_process_html_search_locator"
            ], [
            &$object_call
            ]
        );
        return $object_call;
    }

    private function ups_eu_woo_check_update_type_ap(&$object_call)
    {
        $object_call->info_rateShopAP = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), $this->call_user_method_rateshop
            ], [
            $this->ups_eu_woo_get_rate_shop($object_call, "AP"), &$object_call, "AP"
            ]
        );
        if ($object_call->info_rateShopAP->check_api_response == "{$this->status_cal_api_ok}" &&
            count($object_call->info_rateShopAP->list_services) > 0) {
            foreach ($object_call->info_rateShopAP->list_services as $item_service) {
                $service_id = intval($item_service->Service->ID_Local);
                if ($service_id > 0) {
                    $object_call->RateTimeInTransit[$service_id] = call_user_func_array(
                        [
                        new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), $this->call_user_method_realtime
                        ], [
                        $this->ups_eu_woo_rate_time_in_transit($object_call, $service_id), &$object_call, $service_id
                        ]
                    );
                }
            }
        }
    }

    private function ups_eu_woo_check_update_type_add(&$object_call)
    {
        $object_call->info_rateShopADD = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), $this->call_user_method_rateshop
            ], [
            $this->ups_eu_woo_get_rate_shop($object_call, "ADD"), &$object_call, "ADD"
            ]
        );
        if ($object_call->info_rateShopADD->check_api_response == "{$this->status_cal_api_ok}" &&
            count($object_call->info_rateShopADD->list_services) > 0) {
            foreach ($object_call->info_rateShopADD->list_services as $item_service) {
                $service_id = intval($item_service->Service->ID_Local);
                if ($service_id > 0) {
                    $object_call->RateTimeInTransit[$service_id] = call_user_func_array(
                        [
                        new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), $this->call_user_method_realtime
                        ], [
                        $this->ups_eu_woo_rate_time_in_transit($object_call, $service_id), &$object_call, $service_id
                        ]
                    );
                }
            }
        }
    }

    public function ups_eu_woo_checkout_load($data_array = [])
    {
        $object_call = new \stdClass();
        $object_call->check_api_all = false;
        call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), "ups_eu_woo_input_params_ajax"
            ], [
            &$object_call
            ]
        );
        /* ---call lactor---- */
        $object_call->info_locator = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), "ups_eu_woo_process_data_locator"
            ], [
            $this->ups_eu_woo_call_locator($object_call), &$object_call
            ]
        );
        if ($object_call->info_locator->check === "{$this->status_cal_api_ok}") {
            $this->ups_eu_woo_check_update_type_ap($object_call);
            $this->ups_eu_woo_check_update_type_add($object_call);
        } else {
            $this->ups_eu_woo_check_update_type_add($object_call);
        }
        $object_call->html = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), "ups_eu_woo_process_html"
            ], [
            &$object_call
            ]
        );
        return $object_call;
    }

    private function ups_eu_woo_call_locator(&$object_call, $type_search = false)
    {
        $api_request_entity = new \UpsEuWoocommerce\models\entities\Ups_Eu_Woo_Api_Request_Entity();
        $this->ups_eu_woo_load_lib_api_ups();
        $data_params = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), "ups_eu_woo_init_params_locator"
            ], [
            &$object_call, $type_search
            ]
        );

        $data_search = new \stdClass();
        $data_search->address = $data_params["fullAddress"];
        $data_search->country_code = $data_params[$api_request_entity->countryCode];
        $data_search->locale = $data_params[$api_request_entity->Locale];
        $data_search->unit_of_measurement = $data_params[$api_request_entity->UnitOfMeasurement];
        $data_search->maximum_list_size = $data_params[$api_request_entity->MaximumListSize];
        $data_search->nearby = $data_params[$api_request_entity->nearby];

        if ($data_params[$this->check_call] === "{$this->status_cal_api_ok}") {
            $license = $this->get_license();
            /* ---Log before cal api--- */
            $model_logsApi = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Logs_Api();
            $model_logsApi->ups_eu_woo_before_log_api("Locator");
            /* ---End before call log api */
            $response = $this->lib_api_ups->ups_eu_woo_api_locator($data_search, $license);
            /* ---Log after call api--- */
            $this->ups_eu_woo_after_log_api($model_logsApi);
            /* ----End after call api--- */
            if ($response) {
                $result = json_decode($response);
            } else {
                $result = false;
            }
            return $result;
        }
        return false;
    }

    /**
     * Rate ups_eu_woo_get_rate_shop type ADD, AP
     */
    private function ups_eu_woo_get_rate_shop(&$object_call, $service_type = 'AP')
    {
        $this->ups_eu_woo_load_lib_api_ups();
        $data_params = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), "ups_eu_woo_init_params_get_rate_shop"
            ], [
            &$object_call,
            $service_type
            ]
        );
        if ($data_params->{$this->check_call} === "{$this->status_cal_api_ok}") {
            $license = $this->get_license();
            /* ---Log before cal api--- */
            $model_logsApi = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Logs_Api();
            $model_logsApi->ups_eu_woo_before_log_api("_getRateShop{$service_type}");
            /* ---End before call log api */
            $response = $this->lib_api_ups->ups_eu_woo_api_get_rate($data_params, $license);
            /* ---Log after call api--- */
            $this->ups_eu_woo_after_log_api($model_logsApi);
            /* ----End after call api--- */
            $result = false;
            if ($response) {
                $result = json_decode($response);
            }
            return $result;
        }
        return false;
    }

    /**
     * Rate RATETIMEINTRANSIT
     */
    private function ups_eu_woo_rate_time_in_transit(&$object_call, $service_id)
    {
        $this->ups_eu_woo_load_lib_api_ups();
        $data_params = call_user_func_array(
            [
            new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Ups_Shipping_API(), "ups_eu_woo_init_params_rate_time_in_transit"
            ], [
            &$object_call, $service_id
            ]
        );
        if ($data_params->{$this->check_call} === "{$this->status_cal_api_ok}") {
            $license = $this->get_license();
            /* ---Log before cal api--- */
            $model_logsApi = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Logs_Api();
            $model_logsApi->ups_eu_woo_before_log_api("_RateTimeInTransit-{$service_id}");
            /* ---End before call log api */
            $response = $this->lib_api_ups->ups_eu_woo_api_get_rate($data_params, $license);
            /* ---Log after call api--- */
            $this->ups_eu_woo_after_log_api($model_logsApi);
            /* ----End after call api--- */
            $result = false;
            if ($response) {
                $result = json_decode($response);
            }
            return $result;
        }
        return false;
    }
}
