<?php namespace UpsEuWoocommerce\libsystems\lang;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-lang-common.php - The core plugin class.
 * 
 * This is used to load the Common's languages.
 */

include_once(dirname(__FILE__, 3) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_Common_Language');

class Ups_Eu_Woo_Common_Language extends \UpsEuWoocommerce\models\entities\Ups_Eu_Woo_Language_Entity implements Ups_Eu_Woo_Interfaces_Language
{

    protected $list_lang;
    protected $domain;

    public function __construct($domain)
    {
        $this->domain = $domain;
    }
    /*
     * Name function: ups_eu_woo_load_lang
     * Params: empty
     * Return: type array
     * * */

    public function ups_eu_woo_load_lang()
    {
        /* Init variable for reuse */
        $ups_standard = __("UPS® Standard", $this->domain);
        $ups_expedited = __("UPS Expedited®", $this->domain);
        $ups_express_saver = __("UPS Express Saver®", $this->domain);
        $ups_express = __("UPS Express®", $this->domain);
        $ups_express_plus = __("UPS Express Plus®", $this->domain);
        $ups_express_12h = __("UPS Express 12:00", $this->domain);
        $ups_access_point_economy = __("UPS Access Point Economy", $this->domain);
        /* Init lang common in all system */
        $model_config   = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Config();
        /* Get contry_code */
        $model_config->ups_eu_woo_get_by_key($model_config->COUNTRY_CODE);
        /* set country_code value */
        if (! empty($model_config->value)) {
            $country_code = $model_config->value;
        } else {
            $country_code = "GB";
        }
        $languagesCur = get_bloginfo("language");

        $arrLanguages = [
            'pl-PL' => 'pl',
            'en-GB' => 'gb',
            'en-US' => 'us',
            'de-DE' => 'de',
            'es-ES' => 'es',
            'fr-FR' => 'fr',
            'it-IT' => 'it',
            'nl-NL' => 'nl'
        ];
        // url default;
        $urlSupport = 'https://www.ups.com/gb/en/services/technology-integration/ecommerce-plugins.page';
        
        if (array_key_exists($languagesCur, $arrLanguages) || in_array($languagesCur, $arrLanguages)) {
            if (strtolower($country_code) == $arrLanguages[$languagesCur] || strtolower($country_code) == $languagesCur) {
                $urlSupport = 'https://www.ups.com/'. strtolower($country_code) .'/'. strtolower($country_code) .'/services/technology-integration/ecommerce-plugins.page';
            } else {
                $urlSupport = 'https://www.ups.com/'. strtolower($country_code) .'/en/services/technology-integration/ecommerce-plugins.page';
            }
        };
        
        $info_more_account = sprintf(__("For more information on UPS Plugins please click <a target='_blank' href='%s'>this link</a> (opens in a new browser window)", $this->domain), $urlSupport);
        
        $this->list_lang = [
            'Collect on Delivery (COD)' => __("Collect on Delivery (COD)", $this->domain),
            "UpsShippingModule" => __("UPS Shipping Module", $this->domain),
            "To AP" => __("To AP", $this->domain),
            "To Address" => __("To Address", $this->domain),
            "sc_block1" => __("Account", $this->domain),
            "sc_block2" => __("Shipping Services", $this->domain),
            "sc_block3" => __("Cash on Delivery (COD)", $this->domain),
            "sc_block4" => __("Accessorial Services", $this->domain),
            "sc_block5" => __("Default package setting", $this->domain),
            "sc_block6" => __("Checkout Shipping Rates", $this->domain),
            "sc_block7" => __("Complete Configuration", $this->domain),
            "btn_ok" => __("Ok", $this->domain),
            "btn_close" => __("Close", $this->domain),
            "btn_cancel" => __("Cancel", $this->domain),
            "btn_edit" => __("Edit", $this->domain),
            "btn_delete" => __("Delete", $this->domain),
            "btn_save" => __("Save", $this->domain),
            "btn_next" => __("Next", $this->domain),
            "btn_continue" => __("Continue", $this->domain),
            "btn_print" => __("Print", $this->domain),
            "Weight" => __("Weight", $this->domain),
            "Unit" => __("Unit", $this->domain),
            "Dimension" => __("Dimension", $this->domain),
            "Unit" => __("Unit", $this->domain),
            "Length" => __("Length", $this->domain),
            "Width" => __("Width", $this->domain),
            "Height" => __("Height", $this->domain),
            "min_001_max_999999" => __("min = 0.01 max = 9999.99", $this->domain),
            "minlength_1_maxlength_50" => __("minlength = 1 maxlength = 50", $this->domain),
            "save_success" => __("Data saved successfull", $this->domain),
            "PrintForm" => __("Print form", $this->domain),
            "validate_error" => __("Some of the data you entered were not valid. Please check again.", $this->domain),
            "Yes" => __("Yes", $this->domain),
            "No" => __("No", $this->domain),
            "The Account Number existed" => __("Account number already exists in 'Your Payment Account'", $this->domain),
            "UPS_ACSRL_ADDITIONAL_HADING" => __("Additional Handling", $this->domain),
            "UPS_ACSRL_QV_SHIP_NOTIF" => __("Quantum View Ship Notification", $this->domain),
            "UPS_ACSRL_QV_DLV_NOTIF" => __("Quantum View Delivery Notification", $this->domain),
            "UPS_ACSRL_RESIDENTIAL_ADDRESS" => __("Residential Address", $this->domain),
            "UPS_ACSRL_STATURDAY_DELIVERY" => __("Saturday Delivery", $this->domain),
            "UPS_ACSRL_CARBON_NEUTRAL" => __("Carbon Neutral", $this->domain),
            "UPS_ACSRL_DIRECT_DELIVERY_ONLY" => __("Direct Delivery Only", $this->domain),
            "UPS_ACSRL_DECLARED_VALUE" => __("Declared value", $this->domain),
            "UPS_ACSRL_SIGNATURE_REQUIRED" => __("Signature Required", $this->domain),
            "UPS_ACSRL_ADULT_SIG_REQUIRED" => __("Adult Signature Required", $this->domain),
            "UPS_ACSRL_ACCESS_POINT_COD" => __("To Access Point COD", $this->domain),
            "UPS_ACSRL_TO_HOME_COD" => __("To Home COD", $this->domain),
            "UPS_SP_SERV_PL_AP_AP_ECONOMY" => __("UPS Access Point Economy", $this->domain),
            "UPS_SP_SERV_PL_AP_STANDARD" => $ups_standard,
            "UPS_SP_SERV_PL_AP_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_PL_AP_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_PL_AP_EXPRESS" => $ups_express,
            "UPS_SP_SERV_PL_AP_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_PL_ADD_STANDARD" => $ups_standard,
            "UPS_SP_SERV_PL_ADD_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_PL_ADD_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_PL_ADD_EXPRESS" => $ups_express,
            "UPS_SP_SERV_PL_ADD_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_GB_AP_STANDARD" => $ups_standard,
            "UPS_SP_SERV_GB_AP_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_GB_AP_WW_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_GB_AP_EXPRESS" => $ups_express,
            "UPS_SP_SERV_GB_AP_WW_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_GB_ADD_STANDARD" => $ups_standard,
            "UPS_SP_SERV_GB_ADD_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_GB_ADD_WW_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_GB_ADD_EXPRESS" => $ups_express,
            "UPS_SP_SERV_GB_ADD_WW_EXPRESS_PLUS" => $ups_express_plus,
            "Billing Preference" => __("Billing Preference", $this->domain),
            "We could not find any records" => __("We couldn't find any records", $this->domain),
            "COD" => __("COD", $this->domain),
            "Delivery Address" => __("Delivery Address", $this->domain),
            "Order ID" => __("Order ID", $this->domain),
            "Un-Archived Orders" => __("Un-Archived Orders", $this->domain),
            "Un-Archiving Orders" => __("Un-Archiving Orders", $this->domain),
            "Warning" => __("Warning", $this->domain),
            "titleAccessUnArchiving" => __("Warning! Un-Archiving orders will move your orders to Open Orders tab. Click 'OK' to continue, 'Cancel' to go back to the screen.", $this->domain),
            "Country/Territory" => __("Country/Territory", $this->domain),
            "email" => __("Email", $this->domain),
            "phone_number" => __("Phone number", $this->domain),
            "address" => __("Address", $this->domain),
            "postal_code" => __("Postal code", $this->domain),
            "account_name" => __("Account name", $this->domain),
            "account_number" => __("Account number", $this->domain),
            "currency" => __("Currency", $this->domain),
            "open_order" => __("Open Orders", $this->domain),
            "shipments" => __("Shipments", $this->domain),
            "archived_orders" => __("Archived Orders", $this->domain),
            "order_date" => __("Order Date", $this->domain),
            "order_time" => __("Order Time", $this->domain),
            "product" => __("Product", $this->domain),
            "shipping_service" => __("Shipping Service", $this->domain),
            'Customer Address line 1' => __("Customer Address line 1", $this->domain),
            'Customer Address line 2' => __("Customer Address line 2", $this->domain),
            'Customer Address line 3' => __("Customer Address line 3", $this->domain),
            'Customer PostalCode' => __("Customer PostalCode", $this->domain),
            'Customer City' => __("Customer City", $this->domain),
            'Customer StateOrProvince' => __("Customer StateOrProvince", $this->domain),
            'Customer Country' => __("Customer Country", $this->domain),
            'Customer Email' => __("Customer Email", $this->domain),
            'AlternateDeliveryAddressIndicator' => __("AlternateDeliveryAddressIndicator", $this->domain),
            'UPSAccessPointID' => __("UPSAccessPointID", $this->domain),
            'Access Point Address line 1' => __("Access Point Address line 1", $this->domain),
            'Access Point Address line 2' => __("Access Point Address line 2", $this->domain),
            'Access Point Address line 3' => __("Access Point Address line 3", $this->domain),
            'Access Point City' => __("Access Point City", $this->domain),
            'Access Point StateOrProvince' => __("Access Point StateOrProvince", $this->domain),
            'Access Point PostalCode' => __("Access Point PostalCode", $this->domain),
            'Access Point Country' => __("Access Point Country", $this->domain),
            'Shipping service' => __("Shipping service", $this->domain),
            'infor_more_account_note' => __("NOTE: If you have an existing UPS account number, please use the exact registered pickup address (which might be different from your invoice billing address) associated with this account number. Please note that the format of the postal code or zip code should exactly match the one provided in the registered pickup address.", $this->domain),
            'pickup_address' => __("Pickup Address", $this->domain),
            'tooltip_pickup_address' => __("Use registered pickup address. If you have any difficulties understanding which address to use, please contact your local UPS sales representative or call the support phone number provided on the “About” page", $this->domain),
            'pickup_postal_code' => __("Pickup Postal Code", $this->domain),
            'tooltip_pickup_postal_code' => __("The format of the postal code should exactly match the one provided in the registered pickup address. If you have any difficulties understanding which address to use, please contact your local UPS sales representative or call the support phone number provided on the “About” page", $this->domain),
            'infor_more_account' => $info_more_account,
            'error_api_try_again' => __("There are errors connecting to the UPS API servers. Please try again.", $this->domain),
            /** languages shipping service DE */
            "UPS_SP_SERV_DE_AP_STANDARD" => $ups_standard,
            "UPS_SP_SERV_DE_AP_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_DE_AP_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_DE_AP_EXPRESS" => $ups_express,
            "UPS_SP_SERV_DE_AP_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_DE_AP_EXPRESS_12H" => $ups_express_12h,
            "UPS_SP_SERV_DE_ADD_STANDARD" => $ups_standard,
            "UPS_SP_SERV_DE_ADD_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_DE_ADD_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_DE_ADD_EXPRESS" => $ups_express,
            "UPS_SP_SERV_DE_ADD_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_DE_ADD_EXPRESS_12H" => $ups_express_12h,
            /** languages shipping service FR */
            "UPS_SP_SERV_FR_AP_ECONOMY" => $ups_access_point_economy,
            "UPS_SP_SERV_FR_AP_STANDARD" => $ups_standard,
            "UPS_SP_SERV_FR_AP_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_FR_AP_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_FR_AP_EXPRESS" => $ups_express,
            "UPS_SP_SERV_FR_AP_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_FR_ADD_STANDARD" => $ups_standard,
            "UPS_SP_SERV_FR_ADD_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_FR_ADD_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_FR_ADD_EXPRESS" => $ups_express,
            "UPS_SP_SERV_FR_ADD_EXPRESS_PLUS" => $ups_express_plus,
            /** languages shipping service NL */
            "UPS_SP_SERV_NL_AP_ECONOMY" => $ups_access_point_economy,
            "UPS_SP_SERV_NL_AP_STANDARD" => $ups_standard,
            "UPS_SP_SERV_NL_AP_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_NL_AP_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_NL_AP_EXPRESS" => $ups_express,
            "UPS_SP_SERV_NL_AP_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_NL_ADD_STANDARD" => $ups_standard,
            "UPS_SP_SERV_NL_ADD_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_NL_ADD_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_NL_ADD_EXPRESS" => $ups_express,
            "UPS_SP_SERV_NL_ADD_EXPRESS_PLUS" => $ups_express_plus,
            /** languages shipping service ES */
            "UPS_SP_SERV_ES_AP_ECONOMY" => $ups_access_point_economy,
            "UPS_SP_SERV_ES_AP_STANDARD" => $ups_standard,
            "UPS_SP_SERV_ES_AP_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_ES_AP_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_ES_AP_EXPRESS" => $ups_express,
            "UPS_SP_SERV_ES_AP_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_ES_ADD_STANDARD" => $ups_standard,
            "UPS_SP_SERV_ES_ADD_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_ES_ADD_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_ES_ADD_EXPRESS" => $ups_express,
            "UPS_SP_SERV_ES_ADD_EXPRESS_PLUS" => $ups_express_plus,
            /** languages shipping service IT */
            "UPS_SP_SERV_IT_AP_ECONOMY" => $ups_access_point_economy,
            "UPS_SP_SERV_IT_AP_STANDARD" => $ups_standard,
            "UPS_SP_SERV_IT_AP_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_IT_AP_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_IT_AP_EXPRESS" => $ups_express,
            "UPS_SP_SERV_IT_AP_EXPRESS_PLUS" => $ups_express_plus,
            "UPS_SP_SERV_IT_ADD_STANDARD" => $ups_standard,
            "UPS_SP_SERV_IT_ADD_EXPEDITED" => $ups_expedited,
            "UPS_SP_SERV_IT_ADD_EXPRESS_SAVER" => $ups_express_saver,
            "UPS_SP_SERV_IT_ADD_EXPRESS" => $ups_express,
            "UPS_SP_SERV_IT_ADD_EXPRESS_PLUS" => $ups_express_plus,
        ];
        return $this->list_lang;
    }
}
