<?php namespace UpsEuWoocommerce\models;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * Currency.php - The core plugin class.
 * 
 * This is used to define the Currency Model.
 */

class Ups_Eu_Woo_Currency
{
    /* Declaration variable private */

    private static $data_currency;

    /*
     * Name function: __construct
     * Params: empty
     * Return: void
     * * */

    public function __construct($model_config)
    {
        if (empty(self::$data_currency)) {
            /* get list currency data */
            self::$data_currency = $this->ups_eu_woo_int_currency();
            if (self::$data_currency === false) {
                /* setup currency data */
                $data_currency = false;
                if ($model_config->ups_eu_woo_get_by_key($model_config->CURRENCY_DATA) === true) {
                    $data_currency = $model_config->value;
                }
                if ($data_currency !== false) {
                    self::$data_currency = json_decode(base64_decode($data_currency));
                }
            } else {
                /* set currency key and value */
                if ($model_config->ups_eu_woo_get_by_key($model_config->CURRENCY_DATA) !== true) {
                    $model_config->key = $model_config->CURRENCY_DATA;
                }
                $model_config->value = base64_encode(json_encode(self::$data_currency));
                /* save currency config */
                $model_config->ups_eu_woo_save();
            }
        }
    }
    /*
     * Name function: ups_eu_woo_int_currency
     * Params: empty
     * Return: type obeject or false
     * * */

    public function ups_eu_woo_int_currency()
    {
        try {
            $url = "http://www.apilayer.net/api/live?access_key=d4836987a11b8b5937e54c8e5482e331&format=1";
            $ch = curl_init();
            $timeout = 0;
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, $timeout);
            $response = curl_exec($ch);
            curl_close($ch);
            $json_object = json_decode($response);
            if (intval($json_object->success) === 1) {
                return $json_object;
            }
        } catch (Exception $ex) {
            return false;
        }
    }
    /*
     * Name function: ups_eu_woo_convert_currency
     * Params:
     *  @from_currency: type string
     *  @to_currencecy: type string
     *  @amount: type f
     *
     * * */

    public function ups_eu_woo_convert_currency($from_currency, $to_currency, $amount)
    {
        if (self::$data_currency === false) {
            return false;
        }
        /* get from_currency need to convert */
        $from_currency = trim(strtoupper($from_currency));
        /* get to_currency need to convert */
        $to_currency = trim(strtoupper($to_currency));

        $object_currency = self::$data_currency->quotes;
        if (is_object($object_currency)) {
            $name_currency_from = "USD{$from_currency}";
            $name_currency_to = "USD{$to_currency}";
            /* check from_currency is not empty */
            if (empty($object_currency->{$name_currency_from})) {
                return false;
            }
            /* check to_currency is not empty */
            if (empty($object_currency->{$name_currency_to})) {
                return false;
            }
            $value_currency_from = $object_currency->{$name_currency_from};
            $value_currency_to = $object_currency->{$name_currency_to};
            /* build convert */
            $results = ($value_currency_to / $value_currency_from) * $amount;
            return round($results, 2);
        }
        return false;
    }
}
