<?php namespace UpsEuWoocommerce\models;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-model-init-data-system.php - The core plugin class.
 * 
 * This is used to define the Ups_Eu_Woo_Init_Data_System Model.
 */

require_once(dirname(__FILE__, 2) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_Init_Data_System');

class Ups_Eu_Woo_Init_Data_System
{
    /*
     * Name function: ups_eu_woo_int_term_table_config
     * Params: empty
     * Return: void
     * * */

    public function ups_eu_woo_int_term_table_config()
    {
        $model_config = new Ups_Eu_Woo_Model_Config();
        $table_name = $model_config->ups_eu_woo_get_table_name();
        /* List row table config for insert */
        $array_insert = [
            "('default','0','{$model_config->ACCEPT_TERM_CONDITION}','2')",
            "('default','0','{$model_config->SHOW_TERM_CONDITION}','0')"
        ];
        $str_values = implode(',', $array_insert);
        /* List colums table config for inserrt */
        $colum_inserts = [
            "`{$model_config->col_scope}`",
            "`{$model_config->col_scope_id}`",
            "`{$model_config->col_key}`",
            "`{$model_config->col_value}`"
        ];
        $str_colums = implode(" , ", $colum_inserts);
        /* Build command insert sql */
        $inserts_sql = "INSERT INTO `{$table_name}` ({$str_colums}) VALUES {$str_values}";
        try {
            /* Save to database */
            global $wpdb;
            $wpdb->query("{$inserts_sql}");
        } catch (Exception $ex) {
            /* Log exception of sql */
            Ups_Eu_Woo_Model_Log_File::ups_eu_woo_log($inserts_sql, $ex);
        }
    }
    /*
     * Name function: ups_eu_woo_int_first_insert_table_config
     * Params: empty
     * Return: void
     * * */

    public function ups_eu_woo_int_first_insert_table_config()
    {
        $model_config = new Ups_Eu_Woo_Model_Config();
        $table_name = $model_config->ups_eu_woo_get_table_name();
        global $wpdb;
        $sqlSelect = "SELECT COUNT(0) as total FROM `{$table_name}`";
        try {
            $results = $wpdb->get_results($sqlSelect);
        } catch (Exception $ex) {
            Ups_Eu_Woo_Model_Log_File::ups_eu_woo_log($sqlSelect, $ex);
        }
        $total = 0;
        if (count($results) > 0) {
            $objectResult = $results[0];
            if (!empty($objectResult) && (!empty($objectResult->total))) {
                $total = $objectResult->total;
            }
        }
        /* List row table config for insert */
        $array_insert = [
            "('default','0','{$model_config->ACCEPT_ACCOUNT}','0')",
            "('default','0','{$model_config->ACCEPT_SHIPPING_SERVICE}','0')",
            "('default','0','{$model_config->ACCEPT_CASH_ON_DELIVERY}','0')",
            "('default','0','{$model_config->ACCEPT_ACCESSORIAL}','0')",
            "('default','0','{$model_config->ACCEPT_PACKAGE_DIMENSION}','0')",
            "('default','0','{$model_config->ACCEPT_DELIVERY_RATES}','0')",
            "('default','0','{$model_config->ACCEPT_BILLING_PREFERENCE}','0')",
            "('default','0','{$model_config->SET_DEFAULT}','')",
            "('default','0','{$model_config->DELIVERY_TO_ACCESS_POINT}','0')",
            "('default','0','{$model_config->NUMBER_OF_ACCESS_POINT_AVAIABLE}','0')",
            "('default','0','{$model_config->DISPLAY_ALL_ACCESS_POINT_IN_RANGE}','0')",
            "('default','0','{$model_config->CHOOSE_ACCOUNT_NUMBER_AP}','0')",
            "('default','0','{$model_config->DELIVERY_TO_SHIPPING_ADDRESS}','0')",
            "('default','0','{$model_config->CHOOSE_ACCOUNT_NUMBER_ADD}','0')",
            "('default','0','{$model_config->CUT_OFF_TIME}','0')",
            "('default','0','{$model_config->ACTIVE}','0')",
            "('default','0','{$model_config->NAME}','0')",
            "('default','0','{$model_config->TITLE}','0')",
            "('default','0','{$model_config->FIXED_PRICE}','0')",
            "('default','0','{$model_config->UPS_ACCEPT_CASH_ON_DELIVERY}','0')"
        ];
        $str_values = implode(',', $array_insert);
        /* List colums table config for inserrt */
        $colum_inserts = [
            "`{$model_config->col_scope}`",
            "`{$model_config->col_scope_id}`",
            "`{$model_config->col_key}`",
            "`{$model_config->col_value}`"
        ];
        $str_colums = implode(" , ", $colum_inserts);
        /* Build command insert sql */
        $inserts_sql = "INSERT INTO `{$table_name}` ({$str_colums}) VALUES {$str_values}";
        try {
            /* Save to database */
            $wpdb->query("{$inserts_sql}");
        } catch (Exception $ex) {
            /* Log exception of sql */
            Ups_Eu_Woo_Model_Log_File::ups_eu_woo_log($inserts_sql, $ex);
        }
    }
    /*
     * Name function: ups_eu_woo_int_first_insert_table_accessorial
     * Params: empty
     * Return: void
     * * */

    public function ups_eu_woo_int_first_insert_table_accessorial()
    {
        $model_accessorial = new Ups_Eu_Woo_Model_Accessorial();
        if ($model_accessorial->ups_eu_woo_check_existing() === false) {
            $table_name = $model_accessorial->ups_eu_woo_get_table_name();
            /* list row table accessorial for insert */
            $array_insert = [
                "('1','UPS_ACSRL_ADDITIONAL_HADING','Additional Handling','100','1','0')",
                "('2','UPS_ACSRL_QV_SHIP_NOTIF','Quantum View Ship Notification','6','1','0')",
                "('3','UPS_ACSRL_QV_DLV_NOTIF','Quantum View Delivery Notification','372','1','0')",
                "('4','UPS_ACSRL_RESIDENTIAL_ADDRESS','Residential Address','270','0','0')",
                "('5','UPS_ACSRL_STATURDAY_DELIVERY','Saturday Delivery','300','0','0')",
                "('6','UPS_ACSRL_CARBON_NEUTRAL','Carbon Neutral','441','1','0')",
                "('7','UPS_ACSRL_DIRECT_DELIVERY_ONLY','Direct Delivery Only','541','0','0')",
                "('8','UPS_ACSRL_DECLARED_VALUE','Declared value','5','0','0')",
                "('9','UPS_ACSRL_SIGNATURE_REQUIRED','Signature Required','2','1','0')",
                "('10','UPS_ACSRL_ADULT_SIG_REQUIRED','Adult Signature Required','3','1','0')",
                "('11','UPS_ACSRL_ACCESS_POINT_COD','To Access Point COD','4','0','0')",
                "('12','UPS_ACSRL_TO_HOME_COD','To Home COD','500','0','0')"
            ];
            $str_values = implode(',', $array_insert);
            $colum_inserts = [
                "`{$model_accessorial->col_id}`",
                "`{$model_accessorial->col_accessorial_key}`",
                "`{$model_accessorial->col_accessorial_name}`",
                "`{$model_accessorial->col_accessorial_code}`",
                "`{$model_accessorial->col_show_config}`",
                "`{$model_accessorial->col_show_shipping}`"
            ];
            $str_colums = implode(" , ", $colum_inserts);
            /* Build command insert sql */
            $inserts_sql = "INSERT INTO `{$table_name}` ({$str_colums}) VALUES {$str_values}";
            try {
                /* Save to database */
                global $wpdb;
                $wpdb->query("{$inserts_sql}");
            } catch (Exception $ex) {
                /* Log exception of sql */
                Ups_Eu_Woo_Model_Log_File::ups_eu_woo_log($inserts_sql, $ex);
            }
        }
    }
    /*
     * Name function: ups_eu_woo_int_first_insert_table_services
     * Params: empty
     * Return: void
     * * */

    public function ups_eu_woo_int_first_insert_table_services()
    {
        $model_services = new Ups_Eu_Woo_Model_Services();
        if ($model_services->ups_eu_woo_check_existing() === false) {
            $table_name = $model_services->ups_eu_woo_get_table_name();
            /* List row table services for insert */
            $array_insert = [
                'line_1' => "('1','PL','AP','UPS_SP_SERV_PL_AP_AP_ECONOMY','UPS_DELI_PL_AP_AP_ECONOMY'," .
                    "'UPS_DELI_PL_AP_AP_ECONOMY_VAL','UPS Access Point Economy','70','39','0','&trade;')",
                'line_2' => "('2','PL','AP','UPS_SP_SERV_PL_AP_STANDARD','UPS_DELI_PL_AP_STANDARD'," .
                    "'UPS_DELI_PL_AP_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_3' => "('3','PL','AP','UPS_SP_SERV_PL_AP_EXPEDITED','UPS_DELI_PL_AP_EXPEDITED'," .
                    "'UPS_DELI_PL_AP_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_4' => "('4','PL','AP','UPS_SP_SERV_PL_AP_EXPRESS_SAVER','UPS_DELI_PL_AP_EXPRESS_SAVER'," .
                    "'UPS_DELI_PL_AP_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_5' => "('5','PL','AP','UPS_SP_SERV_PL_AP_EXPRESS','UPS_DELI_PL_AP_EXPRESS'," .
                    "'UPS_DELI_PL_AP_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_6' => "('6','PL','AP','UPS_SP_SERV_PL_AP_EXPRESS_PLUS','UPS_DELI_PL_AP_EXPRESS_PLUS'," .
                    "'UPS_DELI_PL_AP_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",
                'line_7' => "('7','PL','ADD','UPS_SP_SERV_PL_ADD_STANDARD','UPS_DELI_PL_ADD_STANDARD'," .
                    "'UPS_DELI_PL_ADD_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_8' => "('8','PL','ADD','UPS_SP_SERV_PL_ADD_EXPEDITED','UPS_DELI_PL_ADD_EXPEDITED'," .
                    "'UPS_DELI_PL_ADD_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_9' => "('9','PL','ADD','UPS_SP_SERV_PL_ADD_EXPRESS_SAVER','UPS_DELI_PL_ADD_EXPRESS_SAVER'," .
                    "'UPS_DELI_PL_ADD_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_10' => "('10','PL','ADD','UPS_SP_SERV_PL_ADD_EXPRESS','UPS_DELI_PL_ADD_EXPRESS'," .
                    "'UPS_DELI_PL_ADD_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_11' => "('11','PL','ADD','UPS_SP_SERV_PL_ADD_EXPRESS_PLUS','UPS_DELI_PL_ADD_EXPRESS_PLUS'," .
                    "'UPS_DELI_PL_ADD_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",
                'line_12' => "('12','GB','AP','UPS_SP_SERV_GB_AP_STANDARD','UPS_DELI_GB_AP_STANDARD'," .
                    "'UPS_DELI_GB_AP_STANDARD_VAL','UPS Standard','11','68','0','&reg;')",
                'line_13' => "('13','GB','AP','UPS_SP_SERV_GB_AP_EXPEDITED','UPS_DELI_GB_AP_EXPEDITED'," .
                    "'UPS_DELI_GB_AP_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_14' => "('14','GB','AP','UPS_SP_SERV_GB_AP_WW_SAVER','UPS_DELI_GB_AP_WW_SAVER'," .
                    "'UPS_DELI_GB_AP_WW_SAVER_VAL','UPS Express Saver','65',NULL,'0','&reg;')",
                'line_15' => "('15','GB','AP','UPS_SP_SERV_GB_AP_EXPRESS','UPS_DELI_GB_AP_EXPRESS'," .
                    "'UPS_DELI_GB_AP_EXPRESS_VAL','UPS Express','07',NULL,'0','&reg;')",
                'line_16' => "('16','GB','AP','UPS_SP_SERV_GB_AP_WW_EXPRESS_PLUS','UPS_DELI_GB_AP_WW_EXPRESS_PLUS'," .
                    "'UPS_DELI_GB_AP_WW_EXPRESS_PLUS_VAL','UPS Express Plus','54','21','0','&reg;')",
                'line_17' => "('17','GB','ADD','UPS_SP_SERV_GB_ADD_STANDARD','UPS_DELI_GB_ADD_STANDARD'," .
                    "'UPS_DELI_GB_ADD_STANDARD_VAL','UPS Standard','11','68','0','&reg;')",
                'line_18' => "('18','GB','ADD','UPS_SP_SERV_GB_ADD_EXPEDITED','UPS_DELI_GB_ADD_EXPEDITED'," .
                    "'UPS_DELI_GB_ADD_EXPEDITED_VAL','UPS Expedited','08',NULL,'0','&reg;')",
                'line_19' => "('19','GB','ADD','UPS_SP_SERV_GB_ADD_WW_SAVER','UPS_DELI_GB_ADD_WW_SAVER'," .
                    "'UPS_DELI_GB_ADD_WW_SAVER_VAL','UPS Express Saver','65',NULL,'0','&reg;')",
                'line_20' => "('20','GB','ADD','UPS_SP_SERV_GB_ADD_EXPRESS','UPS_DELI_GB_ADD_EXPRESS'," .
                    "'UPS_DELI_GB_ADD_EXPRESS_VAL','UPS Express','07',NULL,'0','&reg;')",
                'line_21' => "('21','GB','ADD','UPS_SP_SERV_GB_ADD_WW_EXPRESS_PLUS','UPS_DELI_GB_ADD_WW_EXPRESS_PLUS',".
                    "'UPS_DELI_GB_ADD_WW_EXPRESS_PLUS_VAL','UPS Express Plus','54','21','0','&reg;')",

                /** AP DE */
                'line_22' => "('22','DE','AP','UPS_SP_SERV_DE_AP_STANDARD','UPS_DELI_DE_AP_STANDARD'," .
                    "'UPS_DELI_DE_AP_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_23' => "('23','DE','AP','UPS_SP_SERV_DE_AP_EXPEDITED','UPS_DELI_DE_AP_EXPEDITED'," .
                    "'UPS_DELI_DE_AP_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_24' => "('24','DE','AP','UPS_SP_SERV_DE_AP_EXPRESS_SAVER','UPS_DELI_DE_AP_EXPRESS_SAVER'," .
                    "'UPS_DELI_DE_AP_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_25' => "('25','DE','AP','UPS_SP_SERV_DE_AP_EXPRESS','UPS_DELI_DE_AP_EXPRESS'," .
                    "'UPS_DELI_DE_AP_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_26' => "('26','DE','AP','UPS_SP_SERV_DE_AP_EXPRESS_PLUS','UPS_DELI_DE_AP_EXPRESS_PLUS'," .
                    "'UPS_DELI_DE_AP_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",
                'line_27' => "('27','DE','AP','UPS_SP_SERV_DE_AP_EXPRESS_12H','UPS_DELI_DE_AP_EXPRESS_12H'," .
                    "'UPS_DELI_DE_AP_EXPRESS_12H_VAL','UPS Express 12:00','74', NULL,'0','&reg;')",
                
                /** ADD DE */
                'line_28' => "('28','DE','ADD','UPS_SP_SERV_DE_ADD_STANDARD','UPS_DELI_DE_ADD_STANDARD'," .
                    "'UPS_DELI_DE_ADD_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_29' => "('29','DE','ADD','UPS_SP_SERV_DE_ADD_EXPEDITED','UPS_DELI_DE_ADD_EXPEDITED'," .
                    "'UPS_DELI_DE_ADD_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_30' => "('30','DE','ADD','UPS_SP_SERV_DE_ADD_EXPRESS_SAVER','UPS_DELI_DE_ADD_EXPRESS_SAVER'," .
                    "'UPS_DELI_DE_ADD_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_31' => "('31','DE','ADD','UPS_SP_SERV_DE_ADD_EXPRESS','UPS_DELI_DE_ADD_EXPRESS'," .
                    "'UPS_DELI_DE_ADD_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_32' => "('32','DE','ADD','UPS_SP_SERV_DE_ADD_EXPRESS_PLUS','UPS_DELI_DE_ADD_EXPRESS_PLUS'," .
                    "'UPS_DELI_DE_ADD_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",
                'line_56' => "('56','DE','ADD','UPS_SP_SERV_DE_ADD_EXPRESS_12H','UPS_DELI_DE_ADD_EXPRESS_12H'," .
                    "'UPS_DELI_DE_ADD_EXPRESS_12H_VAL','UPS Express 12:00','74', NULL,'0','&reg;')",
                
                /** AP ES */
                'line_33' => "('33','ES','AP','UPS_SP_SERV_ES_AP_STANDARD','UPS_DELI_ES_AP_STANDARD'," .
                    "'UPS_DELI_ES_AP_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_34' => "('34','ES','AP','UPS_SP_SERV_ES_AP_EXPEDITED','UPS_DELI_ES_AP_EXPEDITED'," .
                    "'UPS_DELI_ES_AP_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_35' => "('35','ES','AP','UPS_SP_SERV_ES_AP_EXPRESS_SAVER','UPS_DELI_ES_AP_EXPRESS_SAVER'," .
                    "'UPS_DELI_ES_AP_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_36' => "('36','ES','AP','UPS_SP_SERV_ES_AP_EXPRESS','UPS_DELI_ES_AP_EXPRESS'," .
                    "'UPS_DELI_ES_AP_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_37' => "('37','ES','AP','UPS_SP_SERV_ES_AP_EXPRESS_PLUS','UPS_DELI_ES_AP_EXPRESS_PLUS'," .
                    "'UPS_DELI_ES_AP_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",
            
                /** AP IT */
                'line_38' => "('38','IT','AP','UPS_SP_SERV_IT_AP_STANDARD','UPS_DELI_IT_AP_STANDARD'," .
                    "'UPS_DELI_IT_AP_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_39' => "('39','IT','AP','UPS_SP_SERV_IT_AP_EXPEDITED','UPS_DELI_IT_AP_EXPEDITED'," .
                    "'UPS_DELI_IT_AP_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_40' => "('40','IT','AP','UPS_SP_SERV_IT_AP_EXPRESS_SAVER','UPS_DELI_IT_AP_EXPRESS_SAVER'," .
                    "'UPS_DELI_IT_AP_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_41' => "('41','IT','AP','UPS_SP_SERV_IT_AP_EXPRESS','UPS_DELI_IT_AP_EXPRESS'," .
                    "'UPS_DELI_IT_AP_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_42' => "('42','IT','AP','UPS_SP_SERV_IT_AP_EXPRESS_PLUS','UPS_DELI_IT_AP_EXPRESS_PLUS'," .
                    "'UPS_DELI_IT_AP_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",

                /** AP FR */
                'line_43' => "('43','FR','AP','UPS_SP_SERV_FR_AP_ECONOMY','UPS_DELI_FR_AP_ECONOMY'," .
                    "'UPS_DELI_FR_AP_ECONOMY_VAL','UPS Access Point Economy','70','39','0','&trade;')",
                'line_44' => "('44','FR','AP','UPS_SP_SERV_FR_AP_STANDARD','UPS_DELI_FR_AP_STANDARD'," .
                    "'UPS_DELI_FR_AP_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_45' => "('45','FR','AP','UPS_SP_SERV_FR_AP_EXPEDITED','UPS_DELI_FR_AP_EXPEDITED'," .
                    "'UPS_DELI_FR_AP_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_46' => "('46','FR','AP','UPS_SP_SERV_FR_AP_EXPRESS_SAVER','UPS_DELI_FR_AP_EXPRESS_SAVER'," .
                    "'UPS_DELI_FR_AP_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_47' => "('47','FR','AP','UPS_SP_SERV_FR_AP_EXPRESS','UPS_DELI_FR_AP_EXPRESS'," .
                    "'UPS_DELI_FR_AP_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_48' => "('48','FR','AP','UPS_SP_SERV_FR_AP_EXPRESS_PLUS','UPS_DELI_FR_AP_EXPRESS_PLUS'," .
                    "'UPS_DELI_FR_AP_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",

                /** AP NL */
                'line_50' => "('50','NL','AP','UPS_SP_SERV_NL_AP_ECONOMY','UPS_DELI_NL_AP_ECONOMY'," .
                    "'UPS_DELI_NL_AP_ECONOMY_VAL','UPS Access Point Economy','70','39','0','&trade;')",
                'line_51' => "('51','NL','AP','UPS_SP_SERV_NL_AP_STANDARD','UPS_DELI_NL_AP_STANDARD'," .
                    "'UPS_DELI_NL_AP_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_52' => "('52','NL','AP','UPS_SP_SERV_NL_AP_EXPEDITED','UPS_DELI_NL_AP_EXPEDITED'," .
                    "'UPS_DELI_NL_AP_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_53' => "('53','NL','AP','UPS_SP_SERV_NL_AP_EXPRESS_SAVER','UPS_DELI_NL_AP_EXPRESS_SAVER'," .
                    "'UPS_DELI_NL_AP_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_54' => "('54','NL','AP','UPS_SP_SERV_NL_AP_EXPRESS','UPS_DELI_NL_AP_EXPRESS'," .
                    "'UPS_DELI_NL_AP_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_55' => "('55','NL','AP','UPS_SP_SERV_NL_AP_EXPRESS_PLUS','UPS_DELI_NL_AP_EXPRESS_PLUS'," .
                    "'UPS_DELI_NL_AP_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",

                /** ADD ES */
                'line_57' => "('57','ES','ADD','UPS_SP_SERV_ES_ADD_STANDARD','UPS_DELI_ES_ADD_STANDARD'," .
                    "'UPS_DELI_ES_ADD_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_58' => "('58','ES','ADD','UPS_SP_SERV_ES_ADD_EXPEDITED','UPS_DELI_ES_ADD_EXPEDITED'," .
                    "'UPS_DELI_ES_ADD_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_59' => "('59','ES','ADD','UPS_SP_SERV_ES_ADD_EXPRESS_SAVER','UPS_DELI_ES_ADD_EXPRESS_SAVER'," .
                    "'UPS_DELI_ES_ADD_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_60' => "('60','ES','ADD','UPS_SP_SERV_ES_ADD_EXPRESS','UPS_DELI_ES_ADD_EXPRESS'," .
                    "'UPS_DELI_ES_ADD_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_61' => "('61','ES','ADD','UPS_SP_SERV_ES_ADD_EXPRESS_PLUS','UPS_DELI_ES_ADD_EXPRESS_PLUS'," .
                    "'UPS_DELI_ES_ADD_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",

                /** ADD IT */
                'line_62' => "('62','IT','ADD','UPS_SP_SERV_IT_ADD_STANDARD','UPS_DELI_IT_ADD_STANDARD'," .
                    "'UPS_DELI_IT_ADD_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_63' => "('63','IT','ADD','UPS_SP_SERV_IT_ADD_EXPEDITED','UPS_DELI_IT_ADD_EXPEDITED'," .
                    "'UPS_DELI_IT_ADD_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_64' => "('64','IT','ADD','UPS_SP_SERV_IT_ADD_EXPRESS_SAVER','UPS_DELI_IT_ADD_EXPRESS_SAVER'," .
                    "'UPS_DELI_IT_ADD_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_65' => "('65','IT','ADD','UPS_SP_SERV_IT_ADD_EXPRESS','UPS_DELI_IT_ADD_EXPRESS'," .
                    "'UPS_DELI_IT_ADD_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_66' => "('66','IT','ADD','UPS_SP_SERV_IT_ADD_EXPRESS_PLUS','UPS_DELI_IT_ADD_EXPRESS_PLUS'," .
                    "'UPS_DELI_IT_ADD_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",

                /** ADD FR */
                'line_67' => "('67','FR','ADD','UPS_SP_SERV_FR_ADD_STANDARD','UPS_DELI_FR_ADD_STANDARD'," .
                    "'UPS_DELI_FR_ADD_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_68' => "('68','FR','ADD','UPS_SP_SERV_FR_ADD_EXPEDITED','UPS_DELI_FR_ADD_EXPEDITED'," .
                    "'UPS_DELI_FR_ADD_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_69' => "('69','FR','ADD','UPS_SP_SERV_FR_ADD_EXPRESS_SAVER','UPS_DELI_FR_ADD_EXPRESS_SAVER'," .
                    "'UPS_DELI_FR_ADD_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_70' => "('70','FR','ADD','UPS_SP_SERV_FR_ADD_EXPRESS','UPS_DELI_FR_ADD_EXPRESS'," .
                    "'UPS_DELI_FR_ADD_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_71' => "('71','FR','ADD','UPS_SP_SERV_FR_ADD_EXPRESS_PLUS','UPS_DELI_FR_ADD_EXPRESS_PLUS'," .
                    "'UPS_DELI_FR_ADD_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",

                /** ADD NL */
                'line_72' => "('72','NL','ADD','UPS_SP_SERV_NL_ADD_STANDARD','UPS_DELI_NL_ADD_STANDARD'," .
                    "'UPS_DELI_NL_ADD_STANDARD_VAL','UPS Standard','11','25','0','&reg;')",
                'line_73' => "('73','NL','ADD','UPS_SP_SERV_NL_ADD_EXPEDITED','UPS_DELI_NL_ADD_EXPEDITED'," .
                    "'UPS_DELI_NL_ADD_EXPEDITED_VAL','UPS Expedited','08','05','0','&reg;')",
                'line_74' => "('74','NL','ADD','UPS_SP_SERV_NL_ADD_EXPRESS_SAVER','UPS_DELI_NL_ADD_EXPRESS_SAVER'," .
                    "'UPS_DELI_NL_ADD_EXPRESS_SAVER_VAL','UPS Express Saver','65','26','0','&reg;')",
                'line_75' => "('75','NL','ADD','UPS_SP_SERV_NL_ADD_EXPRESS','UPS_DELI_NL_ADD_EXPRESS'," .
                    "'UPS_DELI_NL_ADD_EXPRESS_VAL','UPS Express','07','24','0','&reg;')",
                'line_76' => "('76','NL','ADD','UPS_SP_SERV_NL_ADD_EXPRESS_PLUS','UPS_DELI_NL_ADD_EXPRESS_PLUS'," .
                    "'UPS_DELI_NL_ADD_EXPRESS_PLUS_VAL','UPS Express Plus','54','23','0','&reg;')",

            ];
            $str_values = implode(',', array_values($array_insert));
            /* List colums table services for inserrt */
            $colum_inserts = [
                "`{$model_services->col_id}`",
                "`{$model_services->col_country_code}`",
                "`{$model_services->col_service_type}`",
                "`{$model_services->col_service_key}`",
                "`{$model_services->col_service_key_delivery}`",
                "`{$model_services->col_service_key_val}`",
                "`{$model_services->col_service_name}`",
                "`{$model_services->col_rate_code}`",
                "`{$model_services->col_tin_t_code}`",
                "`{$model_services->col_service_selected}`",
                "`{$model_services->col_service_symbol}`"
            ];
            $str_colums = implode(" , ", $colum_inserts);
            /* Build command insert sql */
            $inserts_sql = "INSERT INTO `{$table_name}` ({$str_colums}) VALUES {$str_values}";
            try {
                /* Save to database */
                global $wpdb;
                $wpdb->query("{$inserts_sql}");
            } catch (Exception $ex) {
                /* Log exception of sql */
                Ups_Eu_Woo_Model_Log_File::ups_eu_woo_log($inserts_sql, $ex);
            }
        }
    }
}
