<?php namespace UpsEuWoocommerce\models;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-model-options.php - The core plugin class.
 * 
 * This is used to define the Ups_Eu_Woo_Model_Options Model.
 */

require_once(dirname(__FILE__, 2) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_Model_Options');

class Ups_Eu_Woo_Model_Options
{
    private $_code = "code";
    private $_name = "name";
    private $_regex = "regex";
    /**
    * arr Release
    * PL, GB, FR, DE, ES, IT, NL
    */
    const release = ['PL', 'FR'];

    /*
     * Name function: ups_eu_woo_get_currency_list
     * Params: empty
     * Return: type array
     * * */

    public function ups_eu_woo_get_currency_list()
    {
        return [
            "AED" => "Arab Emirates Dirham",
            "ARS" => "Argentina Peso",
            "AUD" => "Australian Dollar",
            "BBD" => "Barbados Dollar",
            "BHD" => "Bahrain Dinar",
            "BRL" => "Brazilian Real",
            "BYN" => "Belarus Ruble",
            "CAD" => "Canadian Dollar",
            "CHF" => "Swiss Franc",
            "CLP" => "Chilean Peso",
            "CNY" => "China Renminbi Yuan",
            "COP" => "Colombian Peso",
            "CRC" => "Costa Rican Colon",
            "CZK" => "Czech Koruna",
            "DKK" => "Danish Kroner",
            "DOP" => "Dom Rep Peso",
            "EUR" => "Euro",
            "GBP" => "Pound Sterling",
            "HKD" => "Hong Kong Dollar",
            "HUF" => "Hungarian Forint",
            "IDR" => "Indonesian Rupiah",
            "INR" => "Indian Rupee",
            "JPY" => "Japanese Yen",
            "KWD" => "Kuwait Dinar",
            "KRW" => "Korean Won",
            "KZT" => "Kazakhstan Tenge",
            "MAD" => "Morocco Dirham",
            "MOP" => "Macau Pataca",
            "MXN" => "Mexican Peso",
            "MYR" => "Malaysian Ringgit",
            "NGN" => "Nigerian Naira",
            "NOK" => "Norway Kroner",
            "NZD" => "New Zealand Dollar",
            "PAB" => "Panamanian Balboa",
            "PHP" => "Philippine Peso",
            "PLN" => "Polish Zloty",
            "RON" => "Romanian Leu",
            "RUB" => "Russia Ruble",
            "SEK" => "Swedish Kroner",
            "SGD" => "Singapore Dollar",
            "THB" => "Thailand Baht",
            "TRY" => "Turkey",
            "TWD" => "Taiwan Dollar",
            "VND" => "Vietnam đồng",
            "UAH" => "Ukraine Hyrvnya",
            "USD" => "U.S. Dollar",
            "ZAR" => "South African Rand"
        ];
    }
    /*
     * Name function: get_country_list
     * Params: empty
     * Return: type array
     * * */

    public function get_country_list()
    {
        $data = [
            /* Poland */
            "PL" => [
                $this->_code => "PL",
                $this->_name => __("Poland", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([0-9]{2})-([0-9]{3,4})?$/",
            ]
        ];
        /* United Kingdom */
         if (in_array("GB", self::release)) {
            $data["GB"] = [
                $this->_code => "GB",
                $this->_name => __("United Kingdom", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Deutsch */
        if (in_array("DE", self::release)) {
            $data["DE"] = [
                $this->_code => "DE",
                $this->_name => __("Germany", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Español */
        if (in_array("ES", self::release)) {
            $data["ES"] = [
                $this->_code => "ES",
                $this->_name => __("Spain", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Italiano */
        if (in_array("IT", self::release)) {
            $data["IT"] = [
                $this->_code => "IT",
                $this->_name => __("Italy", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Nederlands */
        if (in_array("NL", self::release)) {
            $data["NL"] = [
                $this->_code => "NL",
                $this->_name => __("Netherlands", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Français */
        if (in_array("FR", self::release)) {
            $data["FR"] = [
                $this->_code => "FR",
                $this->_name => __("France", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        return $data;
    }
    /*
     * Name function: country_list_define
     * Params: empty
     * Return: type array
     * * */

    public function country_list_define()
    {
        $data = [
            /* Poland */
            "PL" => [
                $this->_code => "PL",
                $this->_name => __("Poland", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([0-9]{2})-([0-9]{3,4})?$/",
            ]
        ];
        /* Deutsch */
        if (in_array("GB", self::release)) {
            $data["GB"] = [
                $this->_code => "GB",
                $this->_name => __("United Kingdom", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Deutsch */
        if (in_array("DE", self::release)) {
            $data["DE"] = [
                $this->_code => "DE",
                $this->_name => __("Germany", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Español */
        if (in_array("ES", self::release)) {
            $data["ES"] = [
                $this->_code => "ES",
                $this->_name => __("Spain", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Italiano */
        if (in_array("IT", self::release)) {
            $data["IT"] = [
                $this->_code => "IT",
                $this->_name => __("Italy", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Nederlands */
        if (in_array("NL", self::release)) {
            $data["NL"] = [
                $this->_code => "NL",
                $this->_name => __("Netherlands", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        /* Français */
        if (in_array("FR", self::release)) {
            $data["FR"] = [
                $this->_code => "FR",
                $this->_name => __("France", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                $this->_regex => "/^([[:alnum:]]{2})\s([[:alnum:]]{3,4})?$/",
            ];
        }
        return $data;
    }
    /*
     * Name function: get_country_name
     * Params:
     *  @country_code: type string
     * Return: type string
     * * */

    public function get_country_name($country_code)
    {
        $country_name = '';
        $country = new \WC_Countries();
        /* get list country in woocommerce */
        $list_country = $country->get_countries();
        if (isset($list_country[$country_code])) {
            $country_name = $list_country[$country_code];
        }
        return $country_name;
    }
    /*
     * Name function: get_state_name
     * Params:
     *  @country_code: type string
     *  @state_code: type string
     * Return: type string
     * * */

    public function get_state_name($country_code, $state_code)
    {
        $state_name = '';
        $country = new \WC_Countries();
        /* get list state in woocommerce */
        $list_state = $country->get_states($country_code);
        if (isset($list_state[$state_code])) {
            $state_name = $list_state[$state_code];
        }
        return $state_name;
    }
    /*
     * Name function: get_unit_weight_list
     * Params: empty
     * Return: type array
     * * */

    public function get_unit_weight_list()
    {
        return [
            "kgs" => __("Kg", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            "lbs" => __("Pounds", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
        ];
    }
    /*
     * Name function: get_unit_dimension_list
     * Params: empty
     * Return: type array
     * * */

    public function get_unit_dimension_list()
    {
        return [
            "cm" => __("Cm", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            "inch" => __("Inch", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
        ];
    }
    /*
     * Name function: get_type_rate
     * Params: empty
     * Return: type array
     * * */

    public function get_type_rate()
    {
        return [
            "1" => __("Flat rates", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            "2" => __("Real time shipping rates", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
        ];
    }
    /*
     * Name function: list_time_day
     * Params: empty
     * Return: type array
     * * */

    public function list_time_day()
    {
        $list_time_day = [];
        /* set start time day */
        $list_time_day['00'] = "12 AM";
        for ($i = 1; $i <= 23; $i++) {
            if ($i < 12) {
                /* set time day am */
                $list_time_day[substr("00{$i}", -2)] = "{$i} AM";
            } else {
                /* set time day pm */
                $pm = $i - 12;
                if ($pm === 0) {
                    $list_time_day[substr("00{$i}", -2)] = "{$i} PM";
                } else {
                    $list_time_day[substr("00{$i}", -2)] = "{$pm} PM";
                }
            }
        }
        $list_time_day[24] = __("Disable", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        return $list_time_day;
    }
    /*
     * Name function: translate_country_name_en_US
     * Params:
     *  @country_code: type string
     * Return: type string
     * * */

    public function translate_country_name_en_US($country_code = 'US')
    {
        /* switch locale to en_US */
        switch_to_locale('en_US');
        /* translate country with en_US language */
        $translation = '';
        if (isset(\WC()->countries->countries["{$country_code}"])) {
            $translation = \WC()->countries->countries["{$country_code}"];
        }
        /* restore previous locale */
        restore_previous_locale();
        return $translation;
    }
    /*
     * Name function: translate_state_name_en_US
     * Params:
     *  @country_code: type string
     *  @state_code: type string
     * Return: type string
     * * */

    public function translate_state_name_en_US($country_code = 'US', $state_code = 'AK')
    {
        /* switch locale to en_US */
        switch_to_locale('en_US');
        /* translate state with en_US language */
        $translation = '';
        if (isset(\WC()->countries->states[$country_code][$state_code])) {
            $translation = \WC()->countries->states[$country_code][$state_code];
        }
        /* restore previous locale */
        restore_previous_locale();
        return $translation;
    }
}
