<?php namespace UpsEuWoocommerce\models;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-model-services.php - The core plugin class.
 * 
 * This is used to define the Ups_Eu_Woo_Model_Services Model.
 */

require_once(dirname(__FILE__, 2) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_Model_Services');

class Ups_Eu_Woo_Model_Services extends entities\Ups_Eu_Woo_Services_Entity implements Ups_Eu_Woo_Interfaces
{
    private $table_name = "";
    private $key_id = "id";
    //------------atributes fields----------------
    public $id;
    public $country_code;
    public $service_type;
    public $service_key;
    public $service_key_delivery;
    public $service_key_val;
    public $service_name;
    public $rate_code;
    public $tin_t_code;
    public $service_selected;
    public $service_symbol;

    /*
     * Name function: __construct
     * Params: empty
     * Return: void
     * * */

    public function __construct()
    {
        parent::__construct();
        global $wpdb;
        $this->table_name = "{$wpdb->prefix}{$this->prefix_ups}services";
        $this->key_id = $this->col_id;
    }
    /*
     * Name function: ups_eu_woo_convert_to_array
     * Params: empty
     * Return: type array
     * * */

    public function ups_eu_woo_convert_to_array()
    {
        $tmpArray = [];
        $tmpArray[$this->col_id] = $this->id;
        $tmpArray[$this->col_country_code] = $this->country_code;
        $tmpArray[$this->col_service_type] = $this->service_type;
        $tmpArray[$this->col_service_key] = $this->service_key;
        $tmpArray[$this->col_service_key_delivery] = $this->service_key_delivery;
        $tmpArray[$this->col_service_key_val] = $this->service_key_val;
        $tmpArray[$this->col_service_name] = $this->service_name;
        $tmpArray[$this->col_rate_code] = $this->rate_code;
        $tmpArray[$this->col_tin_t_code] = $this->tin_t_code;
        $tmpArray[$this->col_service_selected] = $this->service_selected;
        $tmpArray[$this->col_service_symbol] = $this->service_symbol;
        return $tmpArray;
    }
    /*
     * Name function: save
     * Params: empty
     * Return: type boolean
     * * */

    public function ups_eu_woo_save()
    {
        /* check validate */
        if ($this->ups_eu_woo_validate() === true) {
            /* convert data to array */
            $dataArray = $this->ups_eu_woo_convert_to_array();
            /* save data to database */
            $check_save_id = $this->ups_eu_woo_base_save($dataArray, $this->table_name, $this->key_id);
            if ($check_save_id > 0) {
                /* set id after save it */
                $this->{$this->key_id} = $check_save_id;
                return true;
            }
            return false;
        }
        return false;
    }
    /*
     * Name function: ups_eu_woo_get_by_id
     * Params:
     *  @id: type int
     * Return: type boolean
     * * */

    public function ups_eu_woo_get_by_id($id)
    {
        $id = intval($id);
        if ($id > 0) {
            /* get data by id */
            $result_array = $this->ups_eu_woo_base_get_by_id($id, $this->table_name, $this->key_id);
            /* convert result data from array to object */
            $this->ups_eu_woo_base_convert_array_to_object($result_array, $this);
            return $this;
        }
        return false;
    }
    /*
     * Name function: get_list_data_by_condition
     * Params:
     *  @conditions: type array
     *  @limit: type string
     * Return: type array object or false
     * * */

    public function get_list_data_by_condition($conditions = array(), $limit = 'all')
    {
        return $this->ups_eu_woo_base_get_list_data_by_condition($this->table_name, $conditions, $limit);
    }
    /*
     * Name function: delete
     * Params:
     *  @id: int
     * Return: boolean
     * * */

    public function ups_eu_woo_delete($id)
    {
        $id = intval($id);
        if ($id > 0) {
            return $this->ups_eu_woo_base_delete($id, $this->table_name, $this->key_id);
        }
        return false;
    }
    /*
     * Name function: validate
     * Params: empty
     * Return: type array or false
     * * */

    public function ups_eu_woo_validate()
    {
        $tmpValidate = [];
        /* check validate country code is empty  */
        if (empty($this->country_code)) {
            $tmpValidate[$this->col_country_code][$this->msg_error] = __(
                "country_code is empty",
                \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain
            );
        }
        /* check validate service type is empty  */
        if (empty($this->service_type)) {
            $tmpValidate[$this->col_service_type][$this->msg_error] = __(
                "service_type is empty",
                \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain
            );
        }
        /* check validate service key is empty  */
        if (empty($this->service_key)) {
            $tmpValidate[$this->col_service_key][$this->msg_error] = __(
                "service_key is empty",
                \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain
            );
        }
        $result = true;
        if (count($tmpValidate) > 0) {
            $result = $tmpValidate;
        }
        return $result;
    }
    /*
     * Name function: ups_eu_woo_merge_array
     * Params:
     *  @data: type array
     * Return: type object
     * * */

    public function ups_eu_woo_merge_array($data)
    {
        $this->ups_eu_woo_base_convert_array_to_object($data, $this);
    }
    /*
     * Name function: ups_eu_woo_check_existing
     * Params: empty
     * Return: type boolean
     * * */

    public function ups_eu_woo_check_existing()
    {
        return $this->ups_eu_woo_base_check_existing($this->table_name);
    }
    /*
     * Name function: ups_eu_woo_check_validate_existing_list
     * Params:
     *  @service_type: type string
     *  @list_service: type array
     * Return: type boolean
     * * */

    private function ups_eu_woo_check_validate_existing_list($service_type = "AP", $list_service)
    {
        foreach ($list_service as $item) {
            if ($item && "{$item["{$this->col_service_type}"]}" === "{$service_type}") {
                if (!empty($item["{$this->col_service_selected}"])) {
                    $item["{$this->col_service_selected}"] = $item["{$this->col_service_selected}"];
                } else {
                    $item["{$this->col_service_selected}"] = "";
                }
                if ($item["{$this->col_service_selected}"] === "on") {
                    return true;
                }
            }
        }
        return false;
    }
    /*
     * Name function: ups_eu_woo_check_validate_before_save
     * Params:
     *  @DELIVERY_TO_ACCESS_POINT: type int
     *  @DELIVERY_TO_SHIPPING_ADDRESS: type int
     *  @list_service:type array
     * Return: type boolean
     * * */

    public function ups_eu_woo_check_validate_before_save($DELIVERY_TO_ACCESS_POINT, $DELIVERY_TO_SHIPPING_ADDRESS, $list_service)
    {
        $check_ap = true;
        $check_add = true;
        /* check delivery to access point and shipping to address is not equal 1 */
        if ($DELIVERY_TO_ACCESS_POINT !== 1 && $DELIVERY_TO_SHIPPING_ADDRESS !== 1) {
            return false;
        }
        /* check delivery to AP */
        if ($DELIVERY_TO_ACCESS_POINT === 1) {
            $check_ap = $this->ups_eu_woo_check_validate_existing_list("AP", $list_service);
        }
        /* validate AP list exist false */
        if ($check_ap === false) {
            return false;
        }
        /* check shipping to ADD */
        if ($DELIVERY_TO_SHIPPING_ADDRESS === 1) {
            $check_add = $this->ups_eu_woo_check_validate_existing_list("ADD", $list_service);
        }
        return $check_add;
    }
    /*
     * Name function: ups_eu_woo_check_show_service
     * Params:
     *  @list_service:type array
     *  @id_service: type int
     * Return: type boolean
     * * */

    private function ups_eu_woo_check_show_service($list_service, $id_service)
    {
        foreach ($list_service as $item) {
            if ($item) {
                if (intval($item["{$this->col_id}"]) === intval($id_service)) {
                    if (!empty($item["{$this->col_service_selected}"])) {
                        $item["{$this->col_service_selected}"] = $item["{$this->col_service_selected}"];
                    } else {
                        $item["{$this->col_service_selected}"] = "";
                    }
                    if ($item["{$this->col_service_selected}"] === "on") {
                        return true;
                    }
                }
            }
        }
        return false;
    }
    /*
     * Name function: ups_eu_woo_get_type_by_rate_code
     * Params:
     *  @rate_code:type int
     * Return: type string
     * * */

    public function ups_eu_woo_get_type_by_rate_code($rate_code)
    {
        $result = $this->ups_eu_woo_base_get_list_data_by_condition($this->table_name, ["{$this->col_rate_code}" => $rate_code], 1);
        $tmp_service_type = "";
        if ($result) {
            $tmp_service_type = $result[0]->service_type;
        }
        return $tmp_service_type;
    }
    /*
     * Name function: ups_eu_woo_get_type_by_id
     * Params:
     *  @id:type int
     * Return: type string
     * * */

    public function ups_eu_woo_get_type_by_id($id)
    {
        /* get list shipping service by conditions */
        $result = $this->ups_eu_woo_base_get_list_data_by_condition($this->table_name, ["{$this->col_id}" => $id], 1);
        /* Assigned variable is empty */
        $str_tmp = "";
        if ($result) {
            $str_tmp = $result[0]->service_type;
        }
        return $str_tmp;
    }
    /*
     * Name function: ups_eu_woo_init_params
     * Params:
     *  @model_config:type object classs
     *  @country_code: type string
     *  @dataObject: type object
     *  @configs: type object
     *  @ups_services: type string
     *  @model_services: type object class
     * Return: void
     * * */

    public function ups_eu_woo_init_params($model_config, $country_code, &$dataObject, $configs, $ups_services, $model_services)
    {
        $dataObject->configs = new \stdClass();

        $dataObject->list_data_acceptpoint  = $model_services->get_list_data_by_condition(
            [
                "`{$this->col_country_code}` = '{$country_code}' ",
                "`{$this->col_service_type}` = 'AP'"
            ]
        );
        $dataObject->list_data_address_delivery = $model_services->get_list_data_by_condition(
            ["`{$this->col_country_code}` = '{$country_code}' ", "`{$this->col_service_type}` = 'ADD'"]
        );

        if ($dataObject->mess_dont_check === "") {
            $dataObject->configs->DELIVERY_TO_ACCESS_POINT = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->DELIVERY_TO_ACCESS_POINT) === true) {
                $dataObject->configs->DELIVERY_TO_ACCESS_POINT = $model_config->value;
            }

            /* Set NUMBER_OF_ACCESS_POINT_AVAIABLE */
            $dataObject->configs->NUMBER_OF_ACCESS_POINT_AVAIABLE = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->NUMBER_OF_ACCESS_POINT_AVAIABLE) === true) {
                $dataObject->configs->NUMBER_OF_ACCESS_POINT_AVAIABLE = $model_config->value;
            }

            if (empty($dataObject->configs->NUMBER_OF_ACCESS_POINT_AVAIABLE)) {
                $dataObject->configs->NUMBER_OF_ACCESS_POINT_AVAIABLE = 5;
            }

            /* Set DISPLAY_ALL_ACCESS_POINT_IN_RANGE */
            $dataObject->configs->DISPLAY_ALL_ACCESS_POINT_IN_RANGE = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->DISPLAY_ALL_ACCESS_POINT_IN_RANGE) === true) {
                $dataObject->configs->DISPLAY_ALL_ACCESS_POINT_IN_RANGE = $model_config->value;
            }
            if (empty($dataObject->configs->DISPLAY_ALL_ACCESS_POINT_IN_RANGE)) {
                $dataObject->configs->DISPLAY_ALL_ACCESS_POINT_IN_RANGE = 10;
            }

            /* Set CHOOSE_ACCOUNT_NUMBER_AP */
            $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_AP = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->CHOOSE_ACCOUNT_NUMBER_AP) === true) {
                $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_AP = $model_config->value;
            }

            /* Set SET_DEFAULT */
            $dataObject->configs->SET_DEFAULT = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->SET_DEFAULT) === true) {
                $dataObject->configs->SET_DEFAULT = $model_config->value;
            }
            if ($dataObject->configs->SET_DEFAULT === "") {
                $dataObject->configs->SET_DEFAULT = 1;
            }
            /* Set DELIVERY_TO_SHIPPING_ADDRESS */
            $dataObject->configs->DELIVERY_TO_SHIPPING_ADDRESS = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->DELIVERY_TO_SHIPPING_ADDRESS) === true) {
                $dataObject->configs->DELIVERY_TO_SHIPPING_ADDRESS = $model_config->value;
            }
            /* Set CHOOSE_ACCOUNT_NUMBER_ADD */
            $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_ADD = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->CHOOSE_ACCOUNT_NUMBER_ADD) === true) {
                $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_ADD = $model_config->value;
            }

            /* Set CUT_OFF_TIME */
            if ($model_config->ups_eu_woo_get_by_key($model_config->CUT_OFF_TIME) === true) {
                $dataObject->configs->CUT_OFF_TIME = $model_config->value;
            } else {
                $dataObject->configs->CUT_OFF_TIME = "17";
            }
            if (strlen($dataObject->configs->CUT_OFF_TIME) < 2) {
                $dataObject->configs->CUT_OFF_TIME = trim("17");
            } else {
                $dataObject->configs->CUT_OFF_TIME = trim($dataObject->configs->CUT_OFF_TIME);
            }

            /* Set CUT_OFF_TIME */
            $dataObject->ACCEPT_SHIPPING_SERVICE = "";
            if ($model_config->ups_eu_woo_get_by_key($model_config->ACCEPT_SHIPPING_SERVICE) === true) {
                $dataObject->ACCEPT_SHIPPING_SERVICE = $model_config->value;
            }
        } else {
            foreach ($dataObject->list_data_acceptpoint as &$item) {
                if ($this->ups_eu_woo_check_show_service($ups_services, $item->id) === true) {
                    $item->service_selected = 1;
                } else {
                    $item->service_selected = 0;
                }
            }
            foreach ($dataObject->list_data_address_delivery as &$item) {
                if ($this->ups_eu_woo_check_show_service($ups_services, $item->id) === true) {
                    $item->service_selected = 1;
                } else {
                    $item->service_selected = 0;
                }
            }

            /* Set DELIVERY_TO_ACCESS_POINT */
            if (array_key_exists($model_config->DELIVERY_TO_ACCESS_POINT, $configs)) {
                $dataObject->configs->DELIVERY_TO_ACCESS_POINT = $configs[$model_config->DELIVERY_TO_ACCESS_POINT];
            } else {
                $dataObject->configs->DELIVERY_TO_ACCESS_POINT = 0;
            }

            /* Set NUMBER_OF_ACCESS_POINT_AVAIABLE */
            if (array_key_exists($model_config->NUMBER_OF_ACCESS_POINT_AVAIABLE, $configs)) {
                $dataObject->configs->NUMBER_OF_ACCESS_POINT_AVAIABLE = $configs[$model_config->NUMBER_OF_ACCESS_POINT_AVAIABLE];
            } else {
                $dataObject->configs->NUMBER_OF_ACCESS_POINT_AVAIABLE = 0;
            }

            /* Set DISPLAY_ALL_ACCESS_POINT_IN_RANGE */
            if (array_key_exists($model_config->DISPLAY_ALL_ACCESS_POINT_IN_RANGE, $configs)) {
                $dataObject->configs->DISPLAY_ALL_ACCESS_POINT_IN_RANGE = $configs[$model_config->DISPLAY_ALL_ACCESS_POINT_IN_RANGE];
            } else {
                $dataObject->configs->DISPLAY_ALL_ACCESS_POINT_IN_RANGE = 0;
            }

            /* Set CHOOSE_ACCOUNT_NUMBER_AP */
            if (array_key_exists($model_config->CHOOSE_ACCOUNT_NUMBER_AP, $configs)) {
                $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_AP = $configs[$model_config->CHOOSE_ACCOUNT_NUMBER_AP];
            } else {
                $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_AP = 0;
            }

            /* Set SET_DEFAULT */
            if (array_key_exists($model_config->SET_DEFAULT, $configs)) {
                $dataObject->configs->SET_DEFAULT = $configs[$model_config->SET_DEFAULT];
            } else {
                $dataObject->configs->SET_DEFAULT = 0;
            }

            /* Set DELIVERY_TO_SHIPPING_ADDRESS */
            if (array_key_exists($model_config->DELIVERY_TO_SHIPPING_ADDRESS, $configs)) {
                $dataObject->configs->DELIVERY_TO_SHIPPING_ADDRESS = $configs[$model_config->DELIVERY_TO_SHIPPING_ADDRESS];
            } else {
                $dataObject->configs->DELIVERY_TO_SHIPPING_ADDRESS = 0;
            }

            /* Set CHOOSE_ACCOUNT_NUMBER_ADD */
            if (array_key_exists($model_config->CHOOSE_ACCOUNT_NUMBER_ADD, $configs)) {
                $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_ADD = $configs[$model_config->CHOOSE_ACCOUNT_NUMBER_ADD];
            } else {
                $dataObject->configs->CHOOSE_ACCOUNT_NUMBER_ADD = 0;
            }

            /* Set CUT_OFF_TIME */
            if (array_key_exists($model_config->CUT_OFF_TIME, $configs)) {
                $dataObject->configs->CUT_OFF_TIME = $configs[$model_config->CUT_OFF_TIME];
            } else {
                $dataObject->configs->CUT_OFF_TIME = 0;
            }
            if (empty($configs[$model_config->ACCEPT_SHIPPING_SERVICE])) {
                $dataObject->ACCEPT_SHIPPING_SERVICE = 0;
            } else {
                $dataObject->ACCEPT_SHIPPING_SERVICE = 1;
            }
        }

        /** handling show */
        $isShowNoteApExpedited  = false;
        $isShowNoteADDExpedited = false;
        
        $arrServiceKeyAp = [
            'UPS_SP_SERV_PL_AP_EXPEDITED',
            'UPS_SP_SERV_GB_AP_EXPEDITED',
            'UPS_SP_SERV_DE_AP_EXPEDITED',
            'UPS_SP_SERV_ES_AP_EXPEDITED',
            'UPS_SP_SERV_IT_AP_EXPEDITED',
            'UPS_SP_SERV_FR_AP_EXPEDITED',
            'UPS_SP_SERV_NL_AP_EXPEDITED'
        ];

        $arrServiceKeyAdd = [
            'UPS_SP_SERV_PL_ADD_EXPEDITED',
            'UPS_SP_SERV_GB_ADD_EXPEDITED',
            'UPS_SP_SERV_DE_ADD_EXPEDITED',
            'UPS_SP_SERV_ES_ADD_EXPEDITED',
            'UPS_SP_SERV_IT_ADD_EXPEDITED',
            'UPS_SP_SERV_FR_ADD_EXPEDITED',
            'UPS_SP_SERV_NL_ADD_EXPEDITED'
        ];

        foreach ($dataObject->list_data_acceptpoint as &$value) {
            if (in_array($value->service_key, $arrServiceKeyAp)) {
                $isShowNoteApExpedited = $value->service_key;
            }
        }
        foreach ($dataObject->list_data_address_delivery as &$value) {
            if (in_array($value->service_key, $arrServiceKeyAdd)) {
                $isShowNoteADDExpedited = $value->service_key;
            }
        }
        
        $dataObject->isShowNoteApExpedited  = $isShowNoteApExpedited;
        $dataObject->isShowNoteADDExpedited = $isShowNoteADDExpedited;
    }
    /*
     * Name function: ups_eu_woo_get_price_service
     * Params:
     *  @service_id:type int
     *  @$api_monetary_value: type float
     *  @$total_order: type float
     *  @$api_currency_code: type string
     *  @$currency_shop: type string
     *  @$config_currency_opnecart: type string
     * Return: type string
     * * */

    public function ups_eu_woo_get_price_service(
    $service_id,
        $api_monetary_value,
        $total_order,
        $api_currency_code,
        $currency_shop,
        $config_currency_opnecart
    ) {
        $model_currency = new Ups_Eu_Woo_Currency(new Ups_Eu_Woo_Model_Config());
        $model_delivery_rates = new Ups_Eu_Woo_Delivery_Rates();

        $api_monetary_value = floatval($api_monetary_value);
        $api_monetary_value_convert = $model_currency->ups_eu_woo_convert_currency(
            $api_currency_code,
            $config_currency_opnecart,
            $api_monetary_value
        );
        $total_order = floatval($total_order);
        $total_order_convert = $model_currency->ups_eu_woo_convert_currency(
            $api_currency_code,
            $config_currency_opnecart,
            $total_order
        );
        $list_delivery_by_service = $model_delivery_rates->ups_eu_woo_get_min_max_delivery_by_service_id($service_id);
        $price = 0;
        if (count($list_delivery_by_service) === 1) {
            $item_delivery = $list_delivery_by_service[0];
            switch ($item_delivery->rate_type) {
                case 1:
                    $price = $this->ups_eu_woo_get_price($item_delivery, $total_order_convert);
                    break;
                case 2:
                    $price = (floatval($item_delivery->delivery_rate) * $api_monetary_value_convert) / 100;
                    break;
                default:
                    break;
            }
        } else {
            foreach ($list_delivery_by_service as $item) {
                if ($total_order <= $item->min_order_value) {
                    $price = $item->delivery_rate;
                    break;
                }
            }
        }
        $price_convert = $model_currency->ups_eu_woo_convert_currency($config_currency_opnecart, $currency_shop, $price);
        return $price_convert;
    }
    /*
     * Name function: ups_eu_woo_get_price
     * Params:
     *  @$item_delivery:type object
     *  @$total_order_convert: type float
     * Return: type string
     * * */

    private function ups_eu_woo_get_price($item_delivery, $total_order_convert)
    {
        $min_order_value = 0;
        if (!empty($item_delivery->min_order_value)) {
            $min_order_value = $item_delivery->min_order_value;
        }
        switch ($item_delivery->min_order_value) {
            case 0:
                $price = $item_delivery->delivery_rate;
                break;
            default:
                if ($total_order_convert <= $item_delivery->min_order_value) {
                    $price = $item_delivery->delivery_rate;
                } else {
                    $price = 0;
                }
                break;
        }

        return $price;
    }
    /*
     * Name function: ups_eu_woo_get_table_name
     * Params: empty
     * Return: type string
     * * */

    public function ups_eu_woo_get_table_name()
    {
        return $this->table_name;
    }
}
