<?php namespace UpsEuWoocommerce\models;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-model-ups-shipping-api.php - The core plugin class.
 * 
 * This is used to define the Ups_Eu_Woo_Model_Ups_Shipping_API Model.
 */

require_once(dirname(__FILE__, 2) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_Model_Ups_Shipping_API');

class Ups_Eu_Woo_Model_Ups_Shipping_API
{

    private $show_params_call_api = false;
    private $descriptions_package_default = [
        'kgs' => "kilograms",
        'lbs' => "Pounds",
        'cm' => "centimeter",
        'inch' => "inch"
    ];
    /* status call api */
    private $status_cal_api_ok = "ok";
    private $status_cal_api_no = "no";
    private $replace_key = '&#xD;';
    private $min_contants_price = 100000000000000;
    private $list_country_cash_on_dilevery = ["BE", "NL", "FR", "ES", "PL", "IT", "DE", "UK"];

    /*
     * Name function: ups_eu_woo_input_params_ajax
     * Params:
     *  @object_call: type object
     * Return: void
     * * */

    public function ups_eu_woo_input_params_ajax(&$object_call)
    {
        $router_url = new \UpsEuWoocommerce\models\bases\Ups_Eu_Woo_Router_Url();
        $model_config = new Ups_Eu_Woo_Model_Config();
        $object_call->input_params_ajax = new \stdClass();

        $fullAddress = "";
        if (!empty($_REQUEST[$model_config->fullAddress])) {
            $fullAddress = strip_tags($_REQUEST[$model_config->fullAddress]);
        }

        if (!empty($_REQUEST[$model_config->billing_address_1])) {
            $object_call->input_params_ajax->billing_address_1 = trim(strip_tags($_REQUEST[$model_config->billing_address_1]));
        } else {
            $object_call->input_params_ajax->billing_address_1 = "";
        }

        if (!empty($_REQUEST[$model_config->billing_address_2])) {
            $object_call->input_params_ajax->billing_address_2 = trim(strip_tags($_REQUEST[$model_config->billing_address_2]));
        } else {
            $object_call->input_params_ajax->billing_address_2 = "";
        }

        if (!empty($_REQUEST[$model_config->billing_country])) {
            $object_call->input_params_ajax->billing_country = trim(strip_tags($_REQUEST[$model_config->billing_country]));
        } else {
            $object_call->input_params_ajax->billing_country = "";
        }

        if (!empty($_REQUEST[$model_config->billing_city])) {
            $object_call->input_params_ajax->billing_city = trim(strip_tags($_REQUEST[$model_config->billing_city]));
        } else {
            $object_call->input_params_ajax->billing_city = "";
        }

        if (!empty($_REQUEST[$model_config->billing_postcode])) {
            $object_call->input_params_ajax->billing_postcode = trim(strip_tags($_REQUEST[$model_config->billing_postcode]));
        } else {
            $object_call->input_params_ajax->billing_postcode = "";
        }

        if (!empty($_REQUEST[$model_config->billing_state])) {
            $object_call->input_params_ajax->billing_state = trim(strip_tags($_REQUEST[$model_config->billing_state]));
        } else {
            $object_call->input_params_ajax->billing_state = "";
        }

        if (!empty($_REQUEST[$model_config->get_cart_total])) {
            $object_call->input_params_ajax->get_cart_total = trim(strip_tags($_REQUEST[$model_config->get_cart_total]));
        } else {
            $object_call->input_params_ajax->get_cart_total = "";
        }

        if (!empty($_REQUEST[$model_config->get_woocommerce_currency_symbol])) {
            $object_call->input_params_ajax->get_woocommerce_currency_symbol = trim(strip_tags($_REQUEST[$model_config->get_woocommerce_currency_symbol]));
        } else {
            $object_call->input_params_ajax->get_woocommerce_currency_symbol = "";
        }

        if (!empty($_REQUEST[$model_config->get_woocommerce_currency])) {
            $object_call->input_params_ajax->get_woocommerce_currency = trim(strip_tags($_REQUEST[$model_config->get_woocommerce_currency]));
        } else {
            $object_call->input_params_ajax->get_woocommerce_currency = "";
        }

        if (!empty($_REQUEST[$model_config->ups_shipping_text_search])) {
            $object_call->input_params_ajax->ups_shipping_text_search = trim(strip_tags($_REQUEST[$model_config->ups_shipping_text_search]));
        } else {
            $object_call->input_params_ajax->ups_shipping_text_search = "";
        }

        if (!empty($_REQUEST[$model_config->ups_shipping_select_search_country])) {
            $object_call->input_params_ajax->ups_shipping_select_search_country = trim(strip_tags($_REQUEST[$model_config->ups_shipping_select_search_country]));
        } else {
            $object_call->input_params_ajax->ups_shipping_select_search_country = "";
        }

        if (!empty($_REQUEST[$model_config->MaximumListSize])) {
            $object_call->input_params_ajax->MaximumListSize = trim(strip_tags($_REQUEST[$model_config->MaximumListSize]));
        } else {
            $object_call->input_params_ajax->MaximumListSize = "";
        }

        if (empty($object_call->input_params_ajax->MaximumListSize)) {
            $object_call->input_params_ajax->MaximumListSize = 1;
        } else {
            $object_call->input_params_ajax->MaximumListSize = intval($object_call->input_params_ajax->MaximumListSize);
        }

        if ($object_call->input_params_ajax->MaximumListSize !== 1) {
            $NUMBER_OF_ACCESS_POINT_AVAIABLE = false;
            if ($model_config->ups_eu_woo_get_by_key("{$model_config->NUMBER_OF_ACCESS_POINT_AVAIABLE}") === true) {
                $NUMBER_OF_ACCESS_POINT_AVAIABLE = $model_config->value;
            }
            if (empty($NUMBER_OF_ACCESS_POINT_AVAIABLE)) {
                $NUMBER_OF_ACCESS_POINT_AVAIABLE = 5;
            }
            $object_call->input_params_ajax->MaximumListSize = $NUMBER_OF_ACCESS_POINT_AVAIABLE;
        }

        if (!empty($_REQUEST[$model_config->ups_eu_woocommerce_key])) {
            $object_call->input_params_ajax->ups_eu_woocommerce_key = trim(strip_tags($_REQUEST[$model_config->ups_eu_woocommerce_key]));
        } else {
            $object_call->input_params_ajax->ups_eu_woocommerce_key = "";
        }

        $COUNTRY_CODE = false;
        if ($model_config->ups_eu_woo_get_by_key($model_config->COUNTRY_CODE) === true) {
            $COUNTRY_CODE = $model_config->value;
        }
        if ($COUNTRY_CODE === false) {
            $COUNTRY_CODE = "en_US";
        } else {
            if ($COUNTRY_CODE == 'PL') {
                $COUNTRY_CODE = "pl_PL";
            } else {
                $COUNTRY_CODE = "en_US";
            }
        }
        $object_call->input_params_ajax->Locale = "{$COUNTRY_CODE}";

        $object_call->input_params_ajax->UnitOfMeasurement = 'KM';

        if ($model_config->ups_eu_woo_get_by_key("{$model_config->DISPLAY_ALL_ACCESS_POINT_IN_RANGE}") === true) {
            $DISPLAY_ALL_ACCESS_POINT_IN_RANGE = $model_config->value;
        } else {
            $DISPLAY_ALL_ACCESS_POINT_IN_RANGE = false;
        }
        if (!empty($DISPLAY_ALL_ACCESS_POINT_IN_RANGE)) {
            $DISPLAY_ALL_ACCESS_POINT_IN_RANGE = $DISPLAY_ALL_ACCESS_POINT_IN_RANGE;
        } else {
            $DISPLAY_ALL_ACCESS_POINT_IN_RANGE = 1;
        }
        $object_call->input_params_ajax->nearby = $DISPLAY_ALL_ACCESS_POINT_IN_RANGE;
    }
    /*
     * Name function: ups_eu_woo_init_params_locator
     * Params:
     *  @object_call: type object
     * Return: type array
     * * */

    public function ups_eu_woo_init_params_locator(&$object_call, $type_search = false)
    {
        $api_request_entity = new entities\Ups_Eu_Woo_Api_Request_Entity();
        $model_config = new Ups_Eu_Woo_Model_Config();
        $data_params = [];
        $data_params[$model_config->check_call] = "{$this->status_cal_api_ok}";
        if (intval($object_call->input_params_ajax->MaximumListSize) === 5) {
            $data_params[$model_config->fullAddress] = "{$object_call->input_params_ajax->ups_shipping_text_search}";
            $data_params[$api_request_entity->countryCode] = "{$object_call->input_params_ajax->ups_shipping_select_search_country}";
        } else {
            $tmp_array = [];
            if (strlen($object_call->input_params_ajax->billing_address_1) > 0) {
                $tmp_array[] = $object_call->input_params_ajax->billing_address_1;
            }
            if (strlen($object_call->input_params_ajax->billing_address_2) > 0) {
                $tmp_array[] = $object_call->input_params_ajax->billing_address_2;
            }
            if (strlen($object_call->input_params_ajax->billing_city) > 0) {
                $tmp_array[] = $object_call->input_params_ajax->billing_city;
            }
            if (strlen($object_call->input_params_ajax->billing_state) > 0) {
                $tmp_array[] = $object_call->input_params_ajax->billing_state;
            }
            if (strlen($object_call->input_params_ajax->billing_postcode) > 0) {
                $tmp_array[] = $object_call->input_params_ajax->billing_postcode;
            }
            $strlen_search = implode(", ", $tmp_array);
            $data_params[$model_config->fullAddress] = "{$strlen_search}";
            $data_params[$api_request_entity->countryCode] = "{$object_call->input_params_ajax->billing_country}";
        }

        $data_params[$api_request_entity->Locale] = "{$object_call->input_params_ajax->Locale}";
        $data_params[$api_request_entity->UnitOfMeasurement] = "{$object_call->input_params_ajax->UnitOfMeasurement}";
        $data_params[$api_request_entity->MaximumListSize] = "{$object_call->input_params_ajax->MaximumListSize}";
        if ($object_call->input_params_ajax->MaximumListSize === 1) {
            $data_params[$api_request_entity->nearby] = "100";
        } else {
            $data_params[$api_request_entity->nearby] = "{$object_call->input_params_ajax->nearby}";
        }
        $this->ups_eu_woo_update_cash_on_delivery($data_params, $object_call, $model_config, $type_search, $api_request_entity);
        $object_call->init_params_Locator = $data_params;
        return $data_params;
    }
    /*
     * Name function: update_cash_on_deliver
     * Params:
     *  @data_params: type array
     *  @result: type object
     * Return: void
     * * */

    private function ups_eu_woo_update_cash_on_delivery(&$data_params, $object_call, $model_config, $type_search, $api_request_entity)
    {
        if ($type_search === true) {
            /* check the case  accept is cash on delivery  get setup */
            $UPS_ACCEPT_CASH_ON_DELIVERY = false;
            if ($model_config->ups_eu_woo_get_by_key($model_config->UPS_ACCEPT_CASH_ON_DELIVERY) === true) {
                $UPS_ACCEPT_CASH_ON_DELIVERY = $model_config->value;
            }

            if (intval($UPS_ACCEPT_CASH_ON_DELIVERY) === 1) {
                /* check coutry code depend list  on delivery  */
                if (in_array($object_call->input_params_ajax->billing_country, $this->list_country_cash_on_dilevery)) {
                    /* update again MaximumListSize and SearchRadiuṣ(nearby) */
                    $MaximumListSize = intval($object_call->input_params_ajax->MaximumListSize) * 2;
                    $data_params[$api_request_entity->MaximumListSize] = "{$MaximumListSize}";
                    $nearby = intval($object_call->input_params_ajax->nearby);
                    $data_params[$api_request_entity->nearby] = "{$nearby}";
                }
            }
        }
    }
    /*
     * Name function: ups_eu_woo_update_value_array
     * Params:
     *  @result: type object
     * Return: array
     * * */

    private function ups_eu_woo_update_value_array($result)
    {
        $tmp_array = [];
        foreach ($result->list_locator as $value) {
            $LocationID = $value->LocationID;
            $value_save = $value->AddressKeyFormat;
            $value_save->PublicAccessPointID = "";
            if (!empty($value->AccessPointInformation) &&
                !empty($value->AccessPointInformation->PublicAccessPointID)) {
                $value_save->PublicAccessPointID = $value->AccessPointInformation->PublicAccessPointID;
            }
            $tmp_array[$LocationID] = $value_save;
        }
        return $tmp_array;
    }
    /*
     * Name function: ups_eu_woo_process_data_locator
     * Params:
     *  @responseObject: type object
     *  @object_call: type object
     * Return: object
     * * */

    public function ups_eu_woo_process_data_locator($responseObject, &$object_call, $type_search_locator = false)
    {
        $result = new \stdClass();
        $result->check = false;
        if (is_object($responseObject)) {
            if (!empty($responseObject->LocatorResponse->Response->ResponseStatusDescription)) {
                if ($responseObject->LocatorResponse->Response->ResponseStatusDescription === "Success") {
                    $model_LogFrontend = new Ups_Eu_Woo_Model_Log_Frontend();
                    if (is_array($responseObject->LocatorResponse->SearchResults->DropLocation)) {
                        $result->Geocode = $responseObject->LocatorResponse->SearchResults->DropLocation[0]->Geocode;
                        $result->AddressKeyFormat = $responseObject->LocatorResponse->SearchResults->DropLocation[0]->AddressKeyFormat;
                        $result->LocationID = $responseObject->LocatorResponse->SearchResults->DropLocation[0]->LocationID;
                        $result->check = "{$this->status_cal_api_ok}";
                        $result->list_locator = $responseObject->LocatorResponse->SearchResults->DropLocation;
                        /* get  tmp_array */
                        $tmp_array = $this->ups_eu_woo_update_value_array($result);
                        /* get update_data_content_by_woocommerce_key */
                        $this->ups_eu_woo_log_data_process_data_locator($tmp_array, $object_call);
                    } else {
                        $result->Geocode = $responseObject->LocatorResponse->SearchResults->DropLocation->Geocode;
                        $result->AddressKeyFormat = $responseObject->LocatorResponse->SearchResults->DropLocation->AddressKeyFormat;
                        $result->LocationID = $responseObject->LocatorResponse->SearchResults->DropLocation->LocationID;
                        $result->check = "{$this->status_cal_api_ok}";
                        $this->ups_eu_woo_check_locator_response_one_ap($type_search_locator, $result, $responseObject, $object_call);
                    }
                    $model_LogFrontend->update_data_content_by_woocommerce_key(
                        $object_call->input_params_ajax->ups_eu_woocommerce_key, ["LocationID" => $result->LocationID]
                    );
                } else {
                    $object_call->api_message_error = $responseObject->LocatorResponse->Response->Error;
                }
            } else {
                $object_call->api_message_error = $responseObject->LocatorResponse->Response->Error;
            }
        }
        return $result;
    }
    /*
     * Name function: ups_eu_woo_check_locator_response_one_ap
     * Params:
     *  @tmp_array: type array
     *  @object_call: type object
     * Return: void
     * * */

    private function ups_eu_woo_check_locator_response_one_ap($type_search_locator, &$result, $responseObject, $object_call)
    {
        if ($type_search_locator == true) {
            if (is_object($responseObject->LocatorResponse->SearchResults->DropLocation)) {
                $result->list_locator[] = $responseObject->LocatorResponse->SearchResults->DropLocation;
                $tmp_array = $this->ups_eu_woo_update_value_array($result);
                /* get update_data_content_by_woocommerce_key */
                $this->ups_eu_woo_log_data_process_data_locator($tmp_array, $object_call);
            }
        }
    }
    /*
     * Name function: ups_eu_woo_log_data_process_data_locator
     * Params:
     *  @tmp_array: type array
     *  @object_call: type object
     * Return: void
     * * */

    private function ups_eu_woo_log_data_process_data_locator($tmp_array, $object_call)
    {
        if (is_array($tmp_array)) {
            $model_LogFrontend = new Ups_Eu_Woo_Model_Log_Frontend();
            $string_update = json_encode($tmp_array);
            $string_update_replace = str_replace($this->replace_key, '', $string_update);
            $model_LogFrontend->update_data_content_by_woocommerce_key(
                $object_call->input_params_ajax->ups_eu_woocommerce_key, ["list_locator" => base64_encode($string_update_replace)]
            );
        }
    }
    /*
     * Name function: load_params_basic
     * Params:
     *  @object_call: type object
     *  @service_type: type string
     * Return: object
     * * */

    private function ups_eu_woo_load_params_basic($object_call, $service_type)
    {
        $model_config = new Ups_Eu_Woo_Model_Config();
        $model_package = new Ups_Eu_Woo_Model_Package_Default();
        $model_account = new Ups_Eu_Woo_Model_Account();
        $object_params = new \stdClass();
        $system_entity = new \UpsEuWoocommerce\models\entities\Ups_Eu_Woo_Systems_Entity();
        $object_params->check_call = "{$this->status_cal_api_ok}";
        $data_params = new \stdClass();
        if (strtoupper(trim($service_type)) === "AP") {
            if ($model_config->ups_eu_woo_get_by_key("{$model_config->DELIVERY_TO_ACCESS_POINT}") === true) {
                $DELIVERY_TO_ACCESS_POINT = $model_config->value;
            } else {
                $DELIVERY_TO_ACCESS_POINT = "";
            }

            if (intval($DELIVERY_TO_ACCESS_POINT) !== 1) {
                $object_params->check_call = "{$this->status_cal_api_no}";
                return $object_params;
            }
            
            if ($model_config->ups_eu_woo_get_by_key("{$model_config->CHOOSE_ACCOUNT_NUMBER_AP}") === true) {
                $CHOOSE_ACCOUNT_NUMBER_AP = $model_config->value;
            } else {
                $CHOOSE_ACCOUNT_NUMBER_AP = "";
            }

            if (intval($CHOOSE_ACCOUNT_NUMBER_AP) > 0) {
                $model_account->ups_eu_woo_get_by_id($CHOOSE_ACCOUNT_NUMBER_AP);
            } else {
                $object_params->check_call = "{$this->status_cal_api_no}";
                return $object_params;
            }
            $data_params->alternate_delivery_address = new \stdClass();
            $data_params->alternate_delivery_address->name = "{$object_call->info_locator->AddressKeyFormat->ConsigneeName}";
            $data_params->alternate_delivery_address->attention_name = " ";
            $address_line = str_replace(
                $this->replace_key, '', $object_call->info_locator->AddressKeyFormat->AddressLine
            );
            $data_params->alternate_delivery_address->address_line = "{$address_line}";
            $data_params->alternate_delivery_address->city = "{$object_call->info_locator->AddressKeyFormat->PoliticalDivision2}";
            $StateProvinceCode = "XX";
            if (!empty($object_call->info_locator->AddressKeyFormat->PoliticalDivision1)) {
                $StateProvinceCode = $object_call->info_locator->AddressKeyFormat->PoliticalDivision1;
            }
            $data_params->alternate_delivery_address->state_code = "{$StateProvinceCode}";
            $data_params->alternate_delivery_address->post_code = "{$object_call->info_locator->AddressKeyFormat->PostcodePrimaryLow}";
            $data_params->alternate_delivery_address->country_code = "{$object_call->info_locator->AddressKeyFormat->CountryCode}";
        } else {
            if ($model_config->ups_eu_woo_get_by_key("{$model_config->DELIVERY_TO_SHIPPING_ADDRESS}") === true) {
                $DELIVERY_TO_SHIPPING_ADDRESS = $model_config->value;
            } else {
                $DELIVERY_TO_SHIPPING_ADDRESS = "";
            }

            if (intval($DELIVERY_TO_SHIPPING_ADDRESS) !== 1) {
                $object_params->check_call = "{$this->status_cal_api_no}";
                return $object_params;
            }

            if ($model_config->ups_eu_woo_get_by_key("{$model_config->CHOOSE_ACCOUNT_NUMBER_ADD}") === true) {
                $CHOOSE_ACCOUNT_NUMBER_ADD = $model_config->value;
            } else {
                $CHOOSE_ACCOUNT_NUMBER_ADD = "";
            }
            
            if (intval($CHOOSE_ACCOUNT_NUMBER_ADD) > 0) {
                $model_account->ups_eu_woo_get_by_id($CHOOSE_ACCOUNT_NUMBER_ADD);
            } else {
                $object_params->check_call = "{$this->status_cal_api_no}";
                return $object_params;
            }
        }
        $data_params->shipper = new \stdClass();
        $data_params->shipper->name = "";
		$data_params->shipper->shipper_number = "{$model_account->ups_account_number}";
		$data_params->shipper->address_line = ["{$model_account->address_1}", "{$model_account->address_2}", "{$model_account->address_3}"];
		$data_params->shipper->city = "{$model_account->city}";
		$data_params->shipper->state_code = "XX";
		$data_params->shipper->post_code = "{$model_account->postal_code}";
        $data_params->shipper->country_code = "{$model_account->country}";

        $data_params->shipfrom = new \stdClass();
        $data_params->shipfrom->name = "";
        $data_params->shipfrom->shipper_number = "{$model_account->ups_account_number}";
		$data_params->shipfrom->address_line = ["{$model_account->address_1}", "{$model_account->address_2}", "{$model_account->address_3}"];
		$data_params->shipfrom->city = "{$model_account->city}";
		$data_params->shipfrom->state_code = "XX";
		$data_params->shipfrom->post_code = "{$model_account->postal_code}";
        $data_params->shipfrom->country_code = "{$model_account->country}";

        $billing_address_1 = str_replace(
            $this->replace_key, '', "{$object_call->input_params_ajax->billing_address_1}"
        );
        $billing_address_2 = str_replace(
            $this->replace_key, '', "{$object_call->input_params_ajax->billing_address_2}"
        );

        $state_code = "XX";
        if (!empty($object_call->info_locator->AddressKeyFormat->PoliticalDivision1)) {
            $state_code = $object_call->info_locator->AddressKeyFormat->PoliticalDivision1;
        }

        $data_params->shipto = new \stdClass();
		$data_params->shipto->name = "";
		$data_params->shipto->shipper_number = "0W73E6";
		$data_params->shipto->address_line = ["{$billing_address_1}", "{$billing_address_2}", ""];
		$data_params->shipto->city = "{$object_call->input_params_ajax->billing_city}";
		$data_params->shipto->state_code = $state_code;
		$data_params->shipto->post_code = "{$object_call->input_params_ajax->billing_postcode}";
        $data_params->shipto->country_code = "{$object_call->input_params_ajax->billing_country}";
        
        $data_params->account_number = "{$model_account->ups_account_number}";

        $model_LogFrontend = new Ups_Eu_Woo_Model_Log_Frontend();
        $model_LogFrontend->update_data_content_by_woocommerce_key(
            $object_call->input_params_ajax->ups_eu_woocommerce_key, [$system_entity->ShipTo => base64_encode(json_encode($data_params->shipto))]
        );

        $list_package = $model_package->get_list_data_by_condition();
        $package_default_item = false;
        if (count($list_package) > 0) {
            $package_default_item = $list_package[0];
        }
        if ($package_default_item) {
            $dimension_description = "";
            if (!empty($this->descriptions_package_default["{$package_default_item->unit_dimension}"])) {
                $dimension_description = $this->descriptions_package_default["{$package_default_item->unit_dimension}"];
            }
            $weight_description = "";
            if (!empty($this->descriptions_package_default["{$package_default_item->unit_weight}"])) {
                $weight_description = $this->descriptions_package_default["{$package_default_item->unit_weight}"];
            }
            $package = new \stdClass();
            $package->dimension = new \stdClass();
            $package->dimension->code = strtoupper($package_default_item->unit_dimension);
            $package->dimension->description = $dimension_description;
            $package->dimension->length = "{$package_default_item->length}";
            $package->dimension->width = "{$package_default_item->width}";
            $package->dimension->height = "{$package_default_item->height}";

            $package->package_weight = new \stdClass();
            $package->package_weight->code = strtoupper($package_default_item->unit_weight);
            $package->package_weight->description = $weight_description;
            $package->package_weight->weight = "{$package_default_item->weight}";

            $data_params->package[] = $package;
        }

        $object_params->data_params = $data_params;
        return $object_params;
    }
    /*
     * Name function: ups_eu_woo_init_params_get_rate_shop
     * Params:
     *  @object_call: type object
     *  @service_type: type string
     * Return: object
     * * */

    public function ups_eu_woo_init_params_get_rate_shop(&$object_call, $service_type = 'AP')
    {
        $model_config = new Ups_Eu_Woo_Model_Config();
        $data_params = new \stdClass();
        $data_params->{$model_config->check_call} = "{$this->status_cal_api_ok}";
        $data_params->shipping_type = "{$service_type}";
        $data_params->typerate = "createshipment";
        $data_params->request_option = "SHOP";

        $load_params_basic = $this->ups_eu_woo_load_params_basic($object_call, $service_type);
        if ($load_params_basic->check_call === "{$this->status_cal_api_no}") {
            $data_params->{$model_config->check_call} = "{$this->status_cal_api_no}";
            return $data_params;
        }

        $data_params->shipper = $load_params_basic->data_params->shipper;
        $data_params->shipfrom = $load_params_basic->data_params->shipfrom;
        $data_params->shipto = $load_params_basic->data_params->shipto;
        $data_params->account_number = $load_params_basic->data_params->account_number;
        $data_params->package = $load_params_basic->data_params->package;

        if ($service_type === 'AP') {
            $data_params->alternate_delivery_address = $load_params_basic->data_params->alternate_delivery_address;
        }

        $params_name = "init_params_getRateShop_{$service_type}";
        if ($this->show_params_call_api === true) {
            $object_call->{$params_name} = $data_params;
        }
        return $data_params;
    }
    /*
     * Name function: ups_eu_woo_process_data_get_rate_shop
     * Params:
     *  @responseObject: type object
     *  @object_call: type object
     *  @service_type: type string
     * Return: object
     * * */

    public function ups_eu_woo_process_data_get_rate_shop($responseObject, &$object_call, $service_type = 'AP')
    {
        $model_services = new Ups_Eu_Woo_Model_Services();
        $model_config = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Config();
        $result = new \stdClass();
        $result->check_api_response = false;
        $result->list_services = [];
        if (is_object($responseObject) && !empty($responseObject->RateResponse->Response->ResponseStatus) &&
            !empty($responseObject->RateResponse->Response->ResponseStatus->Code) &&
            intval($responseObject->RateResponse->Response->ResponseStatus->Code) === 1) {
            $list_api_services = $responseObject->RateResponse->RatedShipment;
            $model_config->ups_eu_woo_get_by_key("COUNTRY_CODE");
            $country_code = $model_config->value;

            $list_config_services = $model_services->get_list_data_by_condition(
                ["`{$model_services->col_country_code}`= '". $country_code. "'", "`{$model_services->col_service_selected}`=1", "`{$model_services->col_service_type}`='{$service_type}'"]
            );
            foreach ($list_api_services as &$item_api) {
                $api_rate_code = $item_api->Service->Code;
                foreach ($list_config_services as $item_config) {
                    $config_rate_code = $item_config->rate_code;
                    if (intval($config_rate_code) === intval($api_rate_code)) {
                        $item_api->Service->Description = $item_config->service_key;
                        $item_api->Service->ID_Local = $item_config->id;
                        $item_api->Service->service_type = $item_config->service_type;
                        $item_api->Service->service_symbol = $item_config->service_symbol;
                        $item_api->Service->get_woocommerce_currency_symbol = $object_call->input_params_ajax->get_woocommerce_currency_symbol;
                        $result->list_services[$item_api->Service->ID_Local] = $item_api;
                    }
                }
            }
            $result->check_api_response = "{$this->status_cal_api_ok}";
        }
        return $result;
    }
    /*
     * Name function: ups_eu_woo_init_params_rate_time_in_transit
     * Params:
     *  @object_call: type object
     *  @service_type: type string
     * Return: object
     * * */

    public function ups_eu_woo_init_params_rate_time_in_transit(&$object_call, $service_id = 0)
    {
        $model_config = new Ups_Eu_Woo_Model_Config();
        $model_services = new Ups_Eu_Woo_Model_Services();
        $model_services->ups_eu_woo_get_by_id($service_id);
        $data_params = new \stdClass();
        $data_params->{$model_config->check_call} = "{$this->status_cal_api_ok}";
        /* Rate API Data RATETIMEINTRANSIT */
        $data_params->shipping_type = "{$model_services->service_type}";
        $data_params->typerate = "createshipment";
        $data_params->request_option = "RATETIMEINTRANSIT";
        $data_params->pickup_date = $model_config->ups_eu_woo_get_cut_off_time();

        $load_params_basic = $this->ups_eu_woo_load_params_basic($object_call, $model_services->service_type);
        if ($load_params_basic->check_call === "{$this->status_cal_api_no}") {
            $data_params->{$model_config->check_call} = "{$this->status_cal_api_no}";
            return $data_params;
        }
        $data_params->shipper = $load_params_basic->data_params->shipper;
        $data_params->shipfrom = $load_params_basic->data_params->shipfrom;
        $data_params->shipto = $load_params_basic->data_params->shipto;
        $data_params->account_number = $load_params_basic->data_params->account_number;
        $data_params->package = $load_params_basic->data_params->package;
        if (strtoupper(trim($data_params->shipping_type)) === 'AP') {
            $data_params->alternate_delivery_address = $load_params_basic->data_params->alternate_delivery_address;
        }

        $data_params->service = new \stdClass();
        $data_params->service->code = "{$model_services->rate_code}";
        $data_params->service->description = "{$model_services->service_name}";

        $data_params->invoice_line_total = new \stdClass();
		$data_params->invoice_line_total->currency_code = "{$object_call->input_params_ajax->get_woocommerce_currency}";
        $data_params->invoice_line_total->monetary_value = "{$object_call->input_params_ajax->get_cart_total}";

        $params_name = "init_params_RateTimeInTransit_{$service_id}";
        if ($this->show_params_call_api === true) {
            $object_call->{$params_name} = $data_params;
        }
        return $data_params;
    }
    /*
     * Name function: ups_eu_woo_process_data_rate_time_in_transit
     * Params:
     *  @responseObject: type object
     *  @object_call: type object
     *  @service_type: type string
     * Return: object
     * * */

    public function ups_eu_woo_process_data_rate_time_in_transit($responseObject, &$object_call, $service_id)
    {
        $result = new \stdClass();
        $result->check = false;
        $result->custom = new \stdClass();
        $result->custom->time_in_transit = '';
        $result->custom->CurrencyCode = '';
        $result->custom->monetary_value = '';

        if (is_object($responseObject) && !empty($responseObject->RateResponse->Response->ResponseStatus) &&
            intval($responseObject->RateResponse->Response->ResponseStatus->Code) === 1) {
            /* processing update  rate and time */
            $result->RatedShipment = $responseObject->RateResponse->RatedShipment;
            $TimeInTransit = $result->RatedShipment->TimeInTransit;
            $arrival_date = $TimeInTransit->ServiceSummary->EstimatedArrival->Arrival->Date;
            $arrival_time = $TimeInTransit->ServiceSummary->EstimatedArrival->Arrival->Time;
            $arrival_dates = date('d F Y', strtotime(substr($arrival_date, 0, 4) . '-' .
                    substr($arrival_date, 4, 2) . '-' . substr($arrival_date, 6, 2)));
            $arrival_dates_format = date_i18n(wc_date_format(), strtotime(substr($arrival_date, 0, 4) . '-' .
                    substr($arrival_date, 4, 2) . '-' . substr($arrival_date, 6, 2)));

            $arrival_times = substr($arrival_time, 0, 2) . ':' . substr($arrival_time, 2, 2);
            $day = $this->ups_eu_woo_convert_date(date('Y-m-d', strtotime($arrival_dates)));
            $list_get_date = $this->ups_eu_woo_get_date();
            if (empty($list_get_date[$this->ups_eu_woo_get_number_key_of_date_by_week($day)])) {
                $date_translate = $day;
            } else {
                $date_translate = $list_get_date[$this->ups_eu_woo_get_number_key_of_date_by_week($day)];
            }

            $to = $arrival_times . ' ' . $day . ' ' . $arrival_dates;
            if ($arrival_times === '23:30') {
                $to = __("Delivered by End of Business Day", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain) . ', ' .
                    $date_translate . ', ' . $arrival_dates_format;
                $to = $this->convertTranslateMonth($to);
            } else {
                $date_format_time_arrival = date_i18n(get_option('time_format'), strtotime("{$arrival_times}"));
                $to = __("Delivered by", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain) . ' ' .
                    $date_format_time_arrival . ', ' . $date_translate . ', ' . $arrival_dates_format;
                $to = $this->convertTranslateMonth($to);
            }
            $result->custom->CurrencyCode = $result->RatedShipment->TotalCharges->CurrencyCode;

            $result->custom->monetary_value = $result->RatedShipment->TotalCharges->MonetaryValue;
            
            $result->custom->service_id = $service_id;

            $result->custom->monetary_value = call_user_func_array(
                [
                new Ups_Eu_Woo_Model_Services(), "ups_eu_woo_get_price_service"
                ], [
                $service_id,
                $result->custom->monetary_value,
                $object_call->input_params_ajax->get_cart_total,
                $result->custom->CurrencyCode,
                $object_call->input_params_ajax->get_woocommerce_currency,
                get_woocommerce_currency()
                ]
            );
            $result->custom->time_in_transit = $to;
            $result->custom->monetary_value_fomart = wc_price($result->custom->monetary_value);
            $result->check = "{$this->status_cal_api_ok}";
        }
        return $result;
    }
    /*
     * Name function: ups_eu_woo_convert_date
     * Params:
     *  @data: type string
     * Return: type string
     * * */

    private function ups_eu_woo_convert_date($date)
    {
        $datetime = date('d', strtotime($date));
        $month = date('m', strtotime($date));
        $year = date('Y', strtotime($date));
        $thoigian = mktime(0, 0, 0, $month, $datetime, $year);
        return strtolower(date("l", $thoigian));
    }
    /*
     * Name function: ups_eu_woo_process_html
     * Params:
     *  @object_call: type object
     * Return: type object
     * * */

    public function ups_eu_woo_process_html(&$object_call)
    {
        $html_object = new \stdClass();
        $model_LogFrontend = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Log_Frontend();
        $model_config = new Ups_Eu_Woo_Model_Config();

        if (!empty($object_call->RateTimeInTransit)) {
            $model_LogFrontend->update_data_content_by_woocommerce_key(
                $object_call->input_params_ajax->ups_eu_woocommerce_key, ["RateTimeInTransit" => base64_encode(json_encode($object_call->RateTimeInTransit))]
            );
        }
        $UpsEuWoocommerceSmarty = new \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Smarty();
        $smarty = $UpsEuWoocommerceSmarty->ups_eu_woo_get_smarty();
        $dataObject = new \stdClass();
        $dataObject->lang = \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::ups_eu_woo_get_lang_by_key($model_LogFrontend->lang_page_checkout);
        $dataObject->data = $object_call;
        $dataObject->get_woocommerce_currency = get_woocommerce_currency();
        $object_call->min_total_price_service = $this->ups_eu_woo_min_total_price_service($object_call);

        if ((!empty($dataObject->data->info_rateShopADD)) && ($dataObject->data->info_rateShopADD->list_services) && (count($dataObject->data->info_rateShopADD->list_services) > 0)) {
            ksort($dataObject->data->info_rateShopADD->list_services);
        }
        if ((!empty($dataObject->data->info_rateShopAP)) && ($dataObject->data->info_rateShopAP->list_services) && (count($dataObject->data->info_rateShopAP->list_services) > 0)) {
            ksort($dataObject->data->info_rateShopAP->list_services);
        }
        $dataObject->CUT_OFF_TIME = "";
        if ($model_config->ups_eu_woo_get_by_key("{$model_config->CUT_OFF_TIME}") === true) {
            $dataObject->CUT_OFF_TIME = $model_config->value;
        }
        $smarty->assign($UpsEuWoocommerceSmarty->dataObject, $dataObject);
        $html_object->html_AP = $smarty->fetch("front/component/list_ap.tpl");
        $html_object->html_ADD = $smarty->fetch("front/component/list_add.tpl");
        $object_call->check_api_all = true;
        return $html_object;
    }
    /*
     * Name function: ups_eu_woo_day_of_week_by_locator_item
     * Params:
     *  @item: type object
     * Return: type object
     * * */

    private function ups_eu_woo_day_of_week_by_locator_item($item)
    {
        $tmp_array = [];
        $language_day = $this->ups_eu_woo_get_date();
        $day_of_week = $item->OperatingHours->StandardHours->DayOfWeek;
        foreach ($day_of_week as $hitem) {
            $object_item = new \stdClass();
            $day = $hitem->Day;
            $object_item->date_name = "";
            if (!empty($language_day["day_{$day}"])) {
                $object_item->date_name = $language_day["day_{$day}"];
            }
            $closed_indicator = '';
            $type = "normal";
            $list_array_open_hours = [];
            $list_array_close_hours = [];
            if (isset($hitem->ClosedIndicator)) {
                $closed_indicator = $hitem->ClosedIndicator;
            }
            $show_open_hours = '';
            if (isset($hitem->OpenHours)) {
                $open_hours = $hitem->OpenHours;
                if (is_array($open_hours)) {
                    $type = "array";
                    foreach ($open_hours as $key => $open_hours_item) {
                        if (strlen($open_hours_item) == 3) {
                            $open_hours_item = '0' . $open_hours_item;
                        }
                        $list_array_open_hours[$key] = substr($open_hours_item, 0, 2) . ':' .
                            substr($open_hours_item, 2, 2);
                    }
                } else {
                    if (strlen($open_hours) == 3) {
                        $open_hours = '0' . $open_hours;
                    }
                    $show_open_hours = substr($open_hours, 0, 2) . ':' . substr($open_hours, 2, 2);
                }
            }
            $show_close_hours = '';
            if (isset($hitem->CloseHours)) {
                $close_hours = $hitem->CloseHours;
                if (is_array($close_hours)) {
                    foreach ($close_hours as $key => $close_hours_item) {
                        if (strlen($close_hours_item) == 3) {
                            $close_hours_item = '0' . $close_hours_item;
                        }
                        $list_array_close_hours[$key] = substr($close_hours_item, 0, 2) . ':' .
                            substr($close_hours_item, 2, 2);
                    }
                } else {
                    if (strlen($close_hours) == 3) {
                        $close_hours = '0' . $close_hours;
                    }
                    $show_close_hours = substr($close_hours, 0, 2) . ':' . substr($close_hours, 2, 2);
                }
            }
            if (isset($hitem->Open24HoursIndicator)) {
                $type = "Open24HoursIndicator";
            }

            $object_item->ClosedIndicator = $closed_indicator;
            $object_item->show_open_hours = $show_open_hours;
            $object_item->show_close_hours = $show_close_hours;
            $object_item->type = $type;
            $object_item->title_open24h = __("Open 24 hours", \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);

            $object_item->list_array_open_hours = $list_array_open_hours;
            $object_item->list_array_close_hours = $list_array_close_hours;

            $tmp_array[$day] = $object_item;
        }
        return $tmp_array;
    }
    /*
     * Name function: day_of_week_by_locator
     * Params:
     *  @list_locator: type array
     * Return: type array object
     * * */

    private function ups_eu_woo_day_of_week_by_locator($list_locator)
    {
        $tmp_array_locator = [];
        if (count($list_locator) > 0) {
            foreach ($list_locator as $item) {
                $LocationID = "";
                if (!empty($item->LocationID)) {
                    $LocationID = $item->LocationID;
                }
                $tmp_array_locator["{$LocationID}"] = $this->ups_eu_woo_day_of_week_by_locator_item($item);
            }
        }
        return $tmp_array_locator;
    }
    /*
     * Name function: ups_eu_woo_process_html_search_locator
     * Params:
     *  @object_call: type object
     * Return: type object
     * * */

    public function ups_eu_woo_process_html_search_locator(&$object_call)
    {
        $html_object = new \stdClass();
        $UpsEuWoocommerceSmarty = new \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Smarty();
        $smarty = $UpsEuWoocommerceSmarty->ups_eu_woo_get_smarty();
        $dataObject = new \stdClass();
        $dataObject->lang = \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::ups_eu_woo_get_lang_by_key(
            $UpsEuWoocommerceSmarty->lang_page_checkout
        );
        $dataObject->data = $object_call;
        if (isset($object_call->info_locator->list_locator)) {
            $dataObject->day_of_week_by_locator = $this->ups_eu_woo_day_of_week_by_locator(
                $object_call->info_locator->list_locator
            );
        }
        $this->ups_eu_woo_build_view_update_cash_on_delivery($dataObject);
        $smarty->assign($UpsEuWoocommerceSmarty->dataObject, $dataObject);
        $html_object->html_bing_map = $smarty->fetch("front/component/list_bing_map.tpl");
        $object_call->check_api_all = true;
        return $html_object;
    }
    /*
     * Name function: ups_eu_woo_build_view_update_cash_on_delivery
     * Params:
     *  @object_call: type object
     * Return: type object
     * * */

    private function ups_eu_woo_build_view_update_cash_on_delivery(&$dataObject)
    {
        $model_config = new Ups_Eu_Woo_Model_Config();
        $UPS_ACCEPT_CASH_ON_DELIVERY = false;
        if ($model_config->ups_eu_woo_get_by_key($model_config->UPS_ACCEPT_CASH_ON_DELIVERY) === true) {
            $UPS_ACCEPT_CASH_ON_DELIVERY = $model_config->value;
        }
        $tmp_list_locator = [];
        if (intval($UPS_ACCEPT_CASH_ON_DELIVERY) === 1) {
            if (in_array($dataObject->data->input_params_ajax->billing_country, $this->list_country_cash_on_dilevery)) {
                $total = count($dataObject->data->info_locator->list_locator);
                for ($index_check = 0; $index_check <= $total; $index_check++) {
                    $ServiceOffering = $dataObject->data->info_locator->list_locator[$index_check]->ServiceOfferingList->ServiceOffering;
                    if ($this->ups_eu_woo_check_code_cash_dilevery_001_011($ServiceOffering) === true) {
                        $tmp_list_locator[] = $dataObject->data->info_locator->list_locator[$index_check];
                    }
                    if (count($tmp_list_locator) >= 5) {
                        break;
                    }
                }
                $dataObject->data->info_locator->list_locator = $tmp_list_locator;
            }
        }
    }
    /*
     * Name function: ups_eu_woo_check_code_cash_dilevery_001_011
     * Params:
     *  @object_call: type object
     * Return: type object
     * * */

    private function ups_eu_woo_check_code_cash_dilevery_001_011($list_ServiceOffering)
    {
        $tmp = [];
        foreach ($list_ServiceOffering as $item) {
            $tmp[] = "{$item->Code}";
        }
        $code_001 = "001";
        $code_011 = "011";
        if (in_array($code_001, $tmp) && in_array($code_011, $tmp)) {
            return true;
        }
        return false;
    }
    /*
     * Name function: ups_eu_woo_get_min_price_in_list
     * Params:
     *  @list_service: type array object
     *  @object_min_service: type object
     *  @list_price: type array
     *  @object_call: type object
     * Return: void
     * * */

    private function ups_eu_woo_get_min_price_in_list($list_service, & $object_min_service, & $list_price, $object_call)
    {
        if (count($list_service) > 0) {
            foreach ($list_service as $item_service) {
                $info_service = $item_service->Service;
                $ID_Local = $info_service->ID_Local;
                if (intval($ID_Local) > 0) {
                    $total_price_by_service = $this->ups_eu_woo_get_total_price_by_service_id($ID_Local, $object_call);
                    if ($total_price_by_service !== false) {
                        $total_price_by_service = floatval($total_price_by_service);
                        if ($object_min_service->min_price_total > $total_price_by_service) {
                            $object_min_service->min_price_total = $total_price_by_service;
                            $object_min_service->id_service = $ID_Local;
                            $object_min_service->service_type = $info_service->service_type;
                            $object_min_service->data = $info_service;
                        }
                    }
                }
            }
        }
    }
    /*
     * Name function: min_total_price_service
     * Params:
     *  @object_call: type object
     * Return: type object
     * * */

    private function ups_eu_woo_min_total_price_service($object_call)
    {
        $model_config = new Ups_Eu_Woo_Model_Config();
        $object_min_service = new \stdClass();
        $object_min_service->min_price_total = $this->min_contants_price;
        $object_min_service->id_service = 0;
        $object_min_service->service_type = '';
        $object_min_service->data = new \stdClass();
        $list_price = [];

        $DELIVERY_TO_ACCESS_POINT = "";
        if ($model_config->ups_eu_woo_get_by_key("{$model_config->DELIVERY_TO_ACCESS_POINT}") === true) {
            $DELIVERY_TO_ACCESS_POINT = $model_config->value;
        }
        $DELIVERY_TO_SHIPPING_ADDRESS = "";
        if ($model_config->ups_eu_woo_get_by_key("{$model_config->DELIVERY_TO_SHIPPING_ADDRESS}") === true) {
            $DELIVERY_TO_SHIPPING_ADDRESS = $model_config->value;
        }
        $SET_DEFAULT = "";
        if ($model_config->ups_eu_woo_get_by_key("{$model_config->SET_DEFAULT}") === true) {
            $SET_DEFAULT = $model_config->value;
        }

        $list_services_AP = [];
        $list_services_ADD = [];
        if ((!empty($object_call->info_rateShopAP) ) && ($object_call->info_rateShopAP->check_api_response === "{$this->status_cal_api_ok}" ) && (count($object_call->info_rateShopAP->list_services) > 0)) {
            $list_services_AP = $object_call->info_rateShopAP->list_services;
        }
        if ((!empty($object_call->info_rateShopADD) ) && ($object_call->info_rateShopADD->check_api_response === "{$this->status_cal_api_ok}" ) && (count($object_call->info_rateShopADD->list_services) > 0)) {
            $list_services_ADD = $object_call->info_rateShopADD->list_services;
        }
        /* the case  type ADD, AP dont existing */
        if ((count($list_services_AP) <= 0) && (count($list_services_ADD) <= 0)) {
            return $object_min_service;
        }
        /* the case  type ADD existing */
        if (count($list_services_AP) <= 0) {
            $this->ups_eu_woo_get_min_price_in_list($list_services_ADD, $object_min_service, $list_price, $object_call);
            return $object_min_service;
        }
        /* the case  type AP existing */
        if (count($list_services_ADD) <= 0) {
            $this->ups_eu_woo_get_min_price_in_list($list_services_AP, $object_min_service, $list_price, $object_call);
            return $object_min_service;
        }
        /* the case type AP,ADD existing */
        if (intval($SET_DEFAULT) === 1) {
            $this->ups_eu_woo_get_min_price_in_list($list_services_AP, $object_min_service, $list_price, $object_call);
            return $object_min_service;
        } else {
            $this->ups_eu_woo_get_min_price_in_list($list_services_AP, $object_min_service, $list_price, $object_call);
            $this->ups_eu_woo_get_min_price_in_list($list_services_ADD, $object_min_service, $list_price, $object_call);
            return $object_min_service;
        }
        return $object_min_service;
    }
    /*
     * Name function: ups_eu_woo_get_total_price_by_service_id
     * Params:
     *  @service_id: type int
     *  @object_call: type object
     * Return: type object or false
     * * */

    private function ups_eu_woo_get_total_price_by_service_id($service_id, $object_call)
    {
        if ($object_call->RateTimeInTransit && $object_call->RateTimeInTransit[$service_id]) {
            $info_rate_time = $object_call->RateTimeInTransit[$service_id];
            if ($info_rate_time->check === "{$this->status_cal_api_ok}") {
                return $info_rate_time->custom->monetary_value;
            }
        }
        return false;
    }
    /*
     * Name function: ups_eu_woo_get_date
     * Params: empty
     * Return: type array
     * * */

    public function ups_eu_woo_get_date()
    {
        $arr_day = [];
        $arr_day['day_2'] = __('Monday', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        $arr_day['day_3'] = __('Tuesday', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        $arr_day['day_4'] = __('Wednesday', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        $arr_day['day_5'] = __('Thursday', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        $arr_day['day_6'] = __('Friday', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        $arr_day['day_7'] = __('Saturday', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        $arr_day['day_1'] = __('Sunday', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        return $arr_day;
    }
    /*
     * Name function: ups_eu_woo_get_number_key_of_date_by_week
     * Params:
     *  @str_date:  type string
     * Return: type string
     * * */

    public function ups_eu_woo_get_number_key_of_date_by_week($str_date)
    {
        $days = [
            'Monday' => "day_2",
            'Tuesday' => "day_3",
            'Wednesday' => "day_4",
            'Thursday' => "day_5",
            'Friday' => "day_6",
            'Saturday' => "day_7",
            'Sunday' => "day_1"
        ];
        $result = "";
        if (!empty($days[ucfirst(trim($str_date))])) {
            $result = $days[ucfirst(trim($str_date))];
        }
        return $result;
    }
    /*
     * Name function: ups_eu_woo_get_number_key_of_date_by_week
     * Params:
     *  @str_date:  type string
     * Return: type string
     * * */

    public function ups_eu_woo_init_params_open_account($data)
    {
        $model_config = new Ups_Eu_Woo_Model_Config();

        $model_license = new Ups_Eu_Woo_Model_License();
        $license_data = $model_license->ups_eu_woo_get_licence_config();
        $username = $license_data->Username;
        /* get address_line_1 */
        $address = $data->address_1;
        /* get address_line_2 */
        if ($data->address_2 != '') {
            $address = $address . ', ' . $data->address_2;
        }
        /* get address_line_3 */
        if ($data->address_3 != '') {
            $address = $address . ', ' . $data->address_3;
        }
        $data->street_address = $address;

        $language_code = get_locale();

        $country_code = "GB";
        if ($model_config->ups_eu_woo_get_by_key($model_config->COUNTRY_CODE) === true) {
            $country_code = $model_config->value;
        }

        $key_code_lang = substr($language_code, 0, 2) . "_" . $country_code;

        $data->language_code = $this->ups_eu_woo_language_code_for_country($key_code_lang);

        $data->username = $username;
        $data->country_code = $country_code;

        return $data;
    }

    private function ups_eu_woo_language_code_for_country($language_code)
    {
        $object = new \stdClass();
        $object->availableCode = array('en_AT', 'de_AT', 'en_BE', 'nl_BE', 'fr_BE', 'en_CZ', 'cs_CZ', 'en_DK', 'da_DK',
            'en_FI', 'fi_FI', 'en_FR', 'fr_FR', 'en_DE', 'de_DE', 'en_GR', 'el_GR', 'en_HU', 'hu_HU', 'en_IE', 'en_IT', 'it_IT',
            'en_LU', 'fr_LU', 'en_NL', 'nl_NL', 'en_NO', 'no_NO', 'en_PL', 'pl_PL', 'en_PT', 'pt_PT', 'en_RU', 'ru_RU', 'en_SI',
            'en_ES', 'es_ES', 'en_SE', 'sv_SE', 'en_CH', 'fr_CH', 'de_CH', 'en_GB');

        if (in_array($language_code, $object->availableCode)) {
            return $language_code;
        } else {
            $language_code = 'en_GB';
            return $language_code;
        }
    }

    /**
     * translate month
     */
    public function convertTranslateMonth($text) {
        $monthArr = [
            'January' => __('January', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'February' => __('February', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'March' => __('March', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'April' => __('April', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'May' => __('May', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'June' => __('June', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'July' => __('July', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'August' => __('August', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'September' => __('September', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'October' => __('October', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'November' => __('November', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
            'December' => __('December', \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
        ];
        foreach ($monthArr as $key => $value) {
            $text = str_replace($key, $value, $text);
        }
        return $text;
    }
}
