<?php namespace UpsEuWoocommerce\setting_shipping;

/**
 * _USER_TECHNICAL_AGREEMENT
 * 
 * @category  ups-shipping-for-woocommerce
 * @package   UPS Shipping and UPS Access Point™ : Official Plugin For WooCommerce
 * @author    United Parcel Service of America, Inc. <noreply@ups.com>
 * @license   This work is Licensed under the Apache License, version 2.0
 * https://www.apache.org/licenses/LICENSE-2.0
 * @copyright (c) 2019, United Parcel Service of America, Inc., all rights reserved
 * @link      https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * 
 * _LICENSE_TAG
 *
 * ups-eu-woo-ups-eu-shipping.php - The core plugin class.
 * 
 * This is used to calculate the shipping.
 */

require_once(dirname(__FILE__, 2) . '/ups-eu-woo-autoloader.php');
new \UpsEuWoocommerce\Ups_Eu_Woo_Main_Autoloader('Ups_Eu_Woo_Ups_Eu_Shipping');

class Ups_Eu_Woo_Ups_Eu_Shipping extends \WC_Shipping_Method
{

    /**
     * Constructor.
     *
     * @param int $instance_id
     */
    private $ups_shipping = 'UPS Shipping';
    private $var_title = 'title';

    public function __construct($instance_id = 0)
    {
        $this->id = 'ups_eu_shipping';
        $this->instance_id = absint($instance_id);
        $this->method_title = __($this->ups_shipping, \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain);
        $this->method_description = __(
            'Description about admin of [UPS Shipping]',
            \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain
        );
        $this->supports = array(
            'shipping-zones',
            'instance-settings',
            'instance-settings-modal',
        );
        $this->init();
    }

    /**
     * Initialize local pickup.
     */
    public function init()
    {

        // Load the settings.
        $this->init_form_fields();
        $this->init_settings();

        // Define user set variables
        $this->title = $this->get_option($this->var_title);
        $this->tax_status = $this->get_option('tax_status');
        $this->cost = $this->get_option('cost');
        if (isset($this->settings['enabled'])) {
            $this->enabled = $this->settings['enabled'];
        } else {
            $this->enabled = 'yes';
        }
        $this->availability = 'including';
        // Actions
        add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
    }

    /**
     * calculate_shipping function.
     * Calculate local pickup shipping.
     *
     * @param array $package
     */
    public function calculate_shipping($package = array())
    {
        $model_config = new \UpsEuWoocommerce\models\Ups_Eu_Woo_Model_Config();
        $ACCEPT_BILLING_PREFERENCE = "";
        if ($model_config->ups_eu_woo_get_by_key($model_config->ACCEPT_BILLING_PREFERENCE) === true) {
            $ACCEPT_BILLING_PREFERENCE = $model_config->value;
        }
        if (intval($ACCEPT_BILLING_PREFERENCE) !== 1) {
            return;
        }
        $this->add_rate(array(
            'label' => $this->title,
            'package' => $package,
            'cost' => $this->cost,
        ));
    }

    /**
     * Init form fields.
     */
    public function init_form_fields()
    {
        $this->instance_form_fields = array(
            $this->var_title => array(
                'title' => __($this->ups_shipping, \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                'type' => 'hidden',
                'description' => __(
                    'Description about frontend [ups eu shipping].',
                    \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain
                ),
                'default' => __($this->ups_shipping, \UpsEuWoocommerce\utils\Ups_Eu_Woo_Utils_Language::$domain),
                'desc_tip' => true,
            )
        );
    }

    public function get_id()
    {
        return $this->id;
    }
}
