<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.ups.com
 * @since             1.0.0
 *
 * @wordpress-plugin
 * Plugin Name:       UPS Shipping and UPS Access Point™ : Official Plugin

 * Description:       This module allows you to easily integrate UPS services into your store with a range of guaranteed delivery services (including deliveries to UPS Access Points™) to meet your customers' need for speed and budget.
 * Version:           1.0.6
 * Author:            UPS
 * Author URI:        https://www.ups.com/pl/en/services/technology-integration/ecommerce-plugins.page
 * License:           GPL-2.0+
 * Text Domain:       ups-eu-woocommerce
 * Domain Path:       /languages
 */
namespace UpsEuWoocommerce;

include_once('src/ups-eu-woo-autoloader.php');
new Ups_Eu_Woo_Main_Autoloader('UpsEuWoocommerce');
//---------------------------------------------------------------------------------------------
/**
 * Check if WooCommerce is active
 * */
$all_plugins = apply_filters('active_plugins', get_option('active_plugins'));
if (stripos(implode($all_plugins), '/woocommerce.php')) {
    if (!defined('UPS_EU_WOO_IMG_PATH')) {
        define('UPS_EU_WOO_IMG_PATH', plugin_dir_url(__FILE__) . 'assets/images/');
    }
    // Define WC_PLUGIN_FILE.
    if (!defined('UPS_EU_WOO_SHIPPING_FILE')) {
        define('UPS_EU_WOO_SHIPPING_FILE', __FILE__);
    }
    // We load Composer's autoload file
    include_once plugin_dir_path(__FILE__) . 'vendor/autoload.php';

    /**
     * The code that runs during plugin activation.
     * This action is documented in includes/class-ups-eu-woocommerce-activator.php
     */
    function activate_plugin_name()
    {
        utils\Ups_Eu_Woo_Utils_Activator::ups_eu_woo_activate();
    }

    /**
     * The code that runs during plugin deactivation.
     * This action is documented in includes/class-ups-eu-woocommerce-deactivator.php
     */
    function deactivate_plugin_name()
    {
        utils\Ups_Eu_Woo_Utils_Deactivator::ups_eu_woo_deactivate();
    }
    register_activation_hook(__FILE__, '\UpsEuWoocommerce\activate_plugin_name');
    register_deactivation_hook(__FILE__, '\UpsEuWoocommerce\deactivate_plugin_name');

    /**
     * Begins execution of the plugin.
     *
     * Since everything within the plugin is registered via hooks,
     * then kicking off the plugin from this point in the file does
     * not affect the page life cycle.
     *
     * @since 1.0.0
     */
    function run_plugin_name()
    {
        $plugin = new Ups_Eu_Woo_Main(new utils\Ups_Eu_Woo_Utils_Loader());
        $plugin->ups_eu_woo_main_run();
    }
    run_plugin_name();

    add_action('admin_footer', "\UpsEuWoocommerce\custom_wp_print_scripts");

    function custom_wp_print_scripts()
    {
        echo call_user_func_array(
            [
            new controllers\front\Ups_Eu_Woo_CheckOut()
            , "custom_wp_print_scripts"
            ], []
        );
    }
    add_filter('woocommerce_shipping_methods', '\UpsEuWoocommerce\add_ups_eu_shipping_method');

    function ups_eu_woo_upgrade_new_version() {
        call_user_func_array([
            new \UpsEuWoocommerce\libsystems\api_ups\Ups_Eu_Woo_Manage_Api_Ups()
            , "ups_eu_woo_upgrade_plugin_version"
        ], []);
    }
    add_action('plugins_loaded','\UpsEuWoocommerce\ups_eu_woo_upgrade_new_version');

    function add_ups_eu_shipping_method($methods)
    {
        $methods["ups_eu_shipping"] = "\UpsEuWoocommerce\setting_shipping\Ups_Eu_Woo_Ups_Eu_Shipping";
        return $methods;
    }
    add_action('woocommerce_review_order_before_payment', '\UpsEuWoocommerce\ups_eu_woo_shipping_build_eshopper');

    function ups_eu_woo_shipping_build_eshopper()
    {
        echo call_user_func_array(
            [
            new controllers\front\Ups_Eu_Woo_CheckOut()
            , "ups_eu_woo_get_html"
            ], []
        );
    }
    add_action('woocommerce_checkout_update_order_meta', '\UpsEuWoocommerce\ups_eu_woocommerce_save_update_order_success');

    function ups_eu_woocommerce_save_update_order_success($order_id)
    {
        call_user_func_array(
            [
            new controllers\front\Ups_Eu_Woo_CheckOut()
            , "ups_eu_woo_front_processing"
            ], [
            $order_id
            ]
        );
    }
    add_action('woocommerce_cancelled_order', '\UpsEuWoocommerce\ups_eu_woo_shipping_change_status_to_refund');

    function ups_eu_woo_shipping_change_status_to_refund($order_id)
    {
        call_user_func_array(
            [
            new controllers\front\Ups_Eu_Woo_CheckOut()
            , "cancel_order"
            ], [
            $order_id
            ]
        );
    }
    add_action('init', "\UpsEuWoocommerce\ups_eu_woo_shipping_ajax_json");

    function ups_eu_woo_shipping_ajax_json()
    {
        $model_RouterUrl = new models\bases\Ups_Eu_Woo_Router_Url();
        $check_frontend_api_json = str_replace(
            $model_RouterUrl->url_home, "", $model_RouterUrl->url_frontend_api_json
        );
        if (strpos($model_RouterUrl->ups_eu_woo_current_location(), $check_frontend_api_json . "&method=") > 0) {
            echo call_user_func_array(
                [
                new controllers\front\Ups_Eu_Woo_CheckOut()
                , "ups_eu_woo_ajax_json"
                ], []
            );
        }
    }
    add_action('woocommerce_after_shipping_rate', '\UpsEuWoocommerce\ups_eu_woo_shipping_method_custom_fields');

    function ups_eu_woo_shipping_method_custom_fields($method)
    {
        if (!is_checkout()) {
            call_user_func_array(
                [
                new controllers\front\Ups_Eu_Woo_CheckOut()
                , "clear_session_data_order_total"
                ], []
            );
            return;
        }
        echo call_user_func_array(
            [
            new controllers\front\Ups_Eu_Woo_CheckOut()
            , "ups_eu_woo_custom_checkout_method_option"
            ], [
            "{$method->method_id}_{$method->instance_id}"
            , $method
            ]
        );
    }
    /* Hide the text "calculate shipping" on the cart page */

    function disable_ups_shipping_calc_on_cart($show_shipping)
    {
        if (is_cart()) {
            echo call_user_func_array(
                [
                new controllers\front\Ups_Eu_Woo_CheckOut()
                , "disable_ups_shipping_calc_on_cart"
                ], []
            );
            return $show_shipping;
        }
        return $show_shipping;
    }
//    add_filter('woocommerce_cart_ready_to_calc_shipping', '\UpsEuWoocommerce\disable_ups_shipping_calc_on_cart');

    /* Upgrage version , by click the button "update now" on the plugin page */
//    add_action('pre_set_site_transient_update_plugins', array(__CLASS__, 'ups_eu_woo_transient_update_plugins'), 21, 1);
//    add_action('ups_eu_woo_upgrader_process_complete', array(__CLASS__, 'ups_eu_woo_upgrader_process_complete'));
} else {
    echo "<h1 class='wp-heading-inline'>Pls, install Woocommerce version 3.2++, before using service the UPS Shipping plugin.</h1>";
    return;
}
